import pytest

# from isapi.install import *


@pytest.mark.skip
def test_AddExtensionFiles():
    AddExtensionFiles()


@pytest.mark.skip
def test_AssignScriptMaps():
    AssignScriptMaps()


@pytest.mark.skip
def test_FindWebServer():
    FindWebServer()


@pytest.mark.skip
def test_GetWebServer():
    GetWebServer()


@pytest.mark.skip
def test_HandleCommandLine():
    HandleCommandLine()


@pytest.mark.skip
def test_InstallModule():
    InstallModule()


@pytest.mark.skip
def test_LocateWebServerPath():
    LocateWebServerPath()


@pytest.mark.skip
def test_MergeStandardOptions():
    MergeStandardOptions()


@pytest.mark.skip
def test_RemoveScriptMaps():
    RemoveScriptMaps()


@pytest.mark.skip
def test_UninstallModule():
    UninstallModule()


@pytest.mark.skip
def test_get_unique_items():
    get_unique_items()


@pytest.mark.skip
def test_split_path():
    split_path()
