import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest

from mapi import *

@pytest.mark.xfail
def test_BinFromHex():
    BinFromHex()     



@pytest.mark.xfail
def test_CloseIMsgSession():
    CloseIMsgSession()     



@pytest.mark.xfail
def test_HexFromBin():
    HexFromBin()     



@pytest.mark.xfail
def test_HrQueryAllRows():
    HrQueryAllRows()     



@pytest.mark.xfail
def test_MAPIAdminProfiles():
    MAPIAdminProfiles()     



@pytest.mark.xfail
def test_MAPIInitialize():
    MAPIInitialize()     



@pytest.mark.xfail
def test_MAPILogonEx():
    MAPILogonEx()     


@pytest.mark.skip
def test_MAPIUninitialize():
    MAPIUninitialize()     



@pytest.mark.xfail
def test_OpenIMsgOnIStg():
    OpenIMsgOnIStg()     


@pytest.mark.skip
def test_OpenIMsgSession():
    OpenIMsgSession()     



@pytest.mark.xfail
def test_RTFStreamToHTML():
    RTFStreamToHTML()     



@pytest.mark.xfail
def test_RTFSync():
    RTFSync()     



@pytest.mark.xfail
def test_WrapCompressedRTFStream():
    WrapCompressedRTFStream()     


