import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32event import *
@pytest.mark.xfail
def test_CancelWaitableTimer():
    CancelWaitableTimer()     



@pytest.mark.xfail
def test_CreateEvent():
    CreateEvent()     



@pytest.mark.xfail
def test_CreateMutex():
    CreateMutex()     



@pytest.mark.xfail
def test_CreateSemaphore():
    CreateSemaphore()     



@pytest.mark.xfail
def test_MsgWaitForMultipleObjects():
    MsgWaitForMultipleObjects()     



@pytest.mark.xfail
def test_MsgWaitForMultipleObjectsEx():
    MsgWaitForMultipleObjectsEx()     



@pytest.mark.xfail
def test_OpenEvent():
    OpenEvent()     



@pytest.mark.xfail
def test_OpenMutex():
    OpenMutex()     



@pytest.mark.xfail
def test_OpenSemaphore():
    OpenSemaphore()     



@pytest.mark.xfail
def test_OpenWaitableTimer():
    OpenWaitableTimer()     



@pytest.mark.xfail
def test_PulseEvent():
    PulseEvent()     



@pytest.mark.xfail
def test_ReleaseMutex():
    ReleaseMutex()     



@pytest.mark.xfail
def test_ReleaseSemaphore():
    ReleaseSemaphore()     



@pytest.mark.xfail
def test_ResetEvent():
    ResetEvent()     



@pytest.mark.xfail
def test_SetEvent():
    SetEvent()     



@pytest.mark.xfail
def test_SetWaitableTimer():
    SetWaitableTimer()     



@pytest.mark.xfail
def test_WaitForInputIdle():
    WaitForInputIdle()     



@pytest.mark.xfail
def test_WaitForMultipleObjects():
    WaitForMultipleObjects()     



@pytest.mark.xfail
def test_WaitForMultipleObjectsEx():
    WaitForMultipleObjectsEx()     



@pytest.mark.xfail
def test_WaitForSingleObject():
    WaitForSingleObject()     



@pytest.mark.xfail
def test_WaitForSingleObjectEx():
    WaitForSingleObjectEx()     


