import pytest
import pytest
import pytest
import pytest
import pytest
from win32lz import *
@pytest.mark.xfail
def test_Close():
    Close()     



@pytest.mark.xfail
def test_Copy():
    Copy()     



@pytest.mark.xfail
def test_GetExpandedName():
    GetExpandedName()     



@pytest.mark.xfail
def test_Init():
    Init()     



@pytest.mark.xfail
def test_OpenFile():
    OpenFile()     


