import pytest

from contextlib import suppress

with suppress(ImportError):
    from win32gui import *


@pytest.mark.skip
def test_AbortPath():
    AbortPath()


@pytest.mark.skip
def test_AlphaBlend():
    AlphaBlend()


@pytest.mark.skip
def test_AngleArc():
    AngleArc()


@pytest.mark.skip
def test_AngleArc():
    AngleArc()


@pytest.mark.skip
def test_AnimateWindow():
    AnimateWindow()


@pytest.mark.skip
def test_AppendMenu():
    AppendMenu()


@pytest.mark.skip
def test_Arc():
    Arc()


@pytest.mark.skip
def test_ArcTo():
    ArcTo()


@pytest.mark.skip
def test_BeginPaint():
    BeginPaint()


@pytest.mark.skip
def test_BeginPath():
    BeginPath()


@pytest.mark.skip
def test_BitBlt():
    BitBlt()


@pytest.mark.skip
def test_BringWindowToTop():
    BringWindowToTop()


@pytest.mark.skip
def test_CallWindowProc():
    CallWindowProc()


@pytest.mark.skip
def test_CheckMenuItem():
    CheckMenuItem()


@pytest.mark.skip
def test_CheckMenuRadioItem():
    CheckMenuRadioItem()


@pytest.mark.skip
def test_ChildWindowFromPoint():
    ChildWindowFromPoint()


@pytest.mark.skip
def test_ChildWindowFromPoint():
    ChildWindowFromPoint()


@pytest.mark.skip
def test_Chord():
    Chord()


@pytest.mark.skip
def test_ClientToScreen():
    ClientToScreen()


@pytest.mark.skip
def test_CloseFigure():
    CloseFigure()


@pytest.mark.skip
def test_CloseWindow():
    CloseWindow()


@pytest.mark.skip
def test_CombineRgn():
    CombineRgn()


@pytest.mark.skip
def test_CombineTransform():
    CombineTransform()


@pytest.mark.skip
def test_CommDlgExtendedError():
    CommDlgExtendedError()


@pytest.mark.skip
def test_CopyIcon():
    CopyIcon()


@pytest.mark.skip
def test_CreateAcceleratorTable():
    CreateAcceleratorTable()


@pytest.mark.skip
def test_CreateBitmap():
    CreateBitmap()


@pytest.mark.skip
def test_CreateBrushIndirect():
    CreateBrushIndirect()


@pytest.mark.skip
def test_CreateCaret():
    CreateCaret()


@pytest.mark.skip
def test_CreateCompatibleBitmap():
    CreateCompatibleBitmap()


@pytest.mark.skip
def test_CreateCompatibleDC():
    CreateCompatibleDC()


@pytest.mark.skip
def test_CreateDC():
    CreateDC()


@pytest.mark.skip
def test_CreateDialogIndirect():
    CreateDialogIndirect()


@pytest.mark.skip
def test_CreateEllipticRgnIndirect():
    CreateEllipticRgnIndirect()


@pytest.mark.skip
def test_CreateFontIndirect():
    CreateFontIndirect()


@pytest.mark.skip
def test_CreateHatchBrush():
    CreateHatchBrush()


@pytest.mark.skip
def test_CreateIconFromResource():
    CreateIconFromResource()


@pytest.mark.skip
def test_CreateIconIndirect():
    CreateIconIndirect()


@pytest.mark.skip
def test_CreateMenu():
    CreateMenu()


@pytest.mark.skip
def test_CreatePatternBrush():
    CreatePatternBrush()


@pytest.mark.skip
def test_CreatePen():
    CreatePen()


@pytest.mark.skip
def test_CreatePolygonRgn():
    CreatePolygonRgn()


@pytest.mark.skip
def test_CreatePopupMenu():
    CreatePopupMenu()


@pytest.mark.skip
def test_CreateRectRgnIndirect():
    CreateRectRgnIndirect()


@pytest.mark.skip
def test_CreateRoundRectRgn():
    CreateRoundRectRgn()


@pytest.mark.skip
def test_CreateSolidBrush():
    CreateSolidBrush()


@pytest.mark.skip
def test_CreateWindow():
    CreateWindow()


@pytest.mark.skip
def test_CreateWindowEx():
    CreateWindowEx()


@pytest.mark.skip
def test_DefWindowProc():
    DefWindowProc()


@pytest.mark.skip
def test_DeleteDC():
    DeleteDC()


@pytest.mark.skip
def test_DeleteMenu():
    DeleteMenu()


@pytest.mark.skip
def test_DeleteObject():
    DeleteObject()


@pytest.mark.skip
def test_DestroyAccleratorTable():
    DestroyAccleratorTable()


@pytest.mark.skip
def test_DestroyCaret():
    DestroyCaret()


@pytest.mark.skip
def test_DestroyIcon():
    DestroyIcon()


@pytest.mark.skip
def test_DestroyMenu():
    DestroyMenu()


@pytest.mark.skip
def test_DestroyWindow():
    DestroyWindow()


@pytest.mark.skip
def test_DialogBox():
    DialogBox()


@pytest.mark.skip
def test_DialogBoxIndirect():
    DialogBoxIndirect()


@pytest.mark.skip
def test_DialogBoxIndirectParam():
    DialogBoxIndirectParam()


@pytest.mark.skip
def test_DialogBoxIndirectParam():
    DialogBoxIndirectParam()


@pytest.mark.skip
def test_DialogBoxParam():
    DialogBoxParam()


@pytest.mark.skip
def test_DispatchMessage():
    DispatchMessage()


@pytest.mark.skip
def test_DragAcceptFiles():
    DragAcceptFiles()


@pytest.mark.skip
def test_DragDetect():
    DragDetect()


@pytest.mark.skip
def test_DrawAnimatedRects():
    DrawAnimatedRects()


@pytest.mark.skip
def test_DrawEdge():
    DrawEdge()


@pytest.mark.skip
def test_DrawFocusRect():
    DrawFocusRect()


@pytest.mark.skip
def test_DrawIcon():
    DrawIcon()


@pytest.mark.skip
def test_DrawIconEx():
    DrawIconEx()


@pytest.mark.skip
def test_DrawMenuBar():
    DrawMenuBar()


@pytest.mark.skip
def test_DrawText():
    DrawText()


@pytest.mark.skip
def test_DrawTextW():
    DrawTextW()


@pytest.mark.skip
def test_Ellipse():
    Ellipse()


@pytest.mark.skip
def test_EnableMenuItem():
    EnableMenuItem()


@pytest.mark.skip
def test_EnableWindow():
    EnableWindow()


@pytest.mark.skip
def test_EndDialog():
    EndDialog()


@pytest.mark.skip
def test_EndPaint():
    EndPaint()


@pytest.mark.skip
def test_EndPath():
    EndPath()


@pytest.mark.skip
def test_EnumChildWindows():
    EnumChildWindows()


@pytest.mark.skip
def test_EnumFontFamilies():
    EnumFontFamilies()


@pytest.mark.skip
def test_EnumPropsEx():
    EnumPropsEx()


@pytest.mark.skip
def test_EnumThreadWindows():
    EnumThreadWindows()


@pytest.mark.skip
def test_EnumWindows():
    EnumWindows()


@pytest.mark.skip
def test_EqualRgn():
    EqualRgn()


@pytest.mark.skip
def test_ExtCreatePen():
    ExtCreatePen()


@pytest.mark.skip
def test_ExtFloodFill():
    ExtFloodFill()


@pytest.mark.skip
def test_ExtTextOut():
    ExtTextOut()


@pytest.mark.skip
def test_ExtractIcon():
    ExtractIcon()


@pytest.mark.skip
def test_ExtractIconEx():
    ExtractIconEx()


@pytest.mark.skip
def test_FillPath():
    FillPath()


@pytest.mark.skip
def test_FillRect():
    FillRect()


@pytest.mark.skip
def test_FillRgn():
    FillRgn()


@pytest.mark.skip
def test_FindWindow():
    FindWindow()


@pytest.mark.skip
def test_FindWindowEx():
    FindWindowEx()


@pytest.mark.skip
def test_FlashWindow():
    FlashWindow()


@pytest.mark.skip
def test_FlashWindowEx():
    FlashWindowEx()


@pytest.mark.skip
def test_FlattenPath():
    FlattenPath()


@pytest.mark.skip
def test_FrameRect():
    FrameRect()


@pytest.mark.skip
def test_FrameRgn():
    FrameRgn()


@pytest.mark.skip
def test_GetActiveWindow():
    GetActiveWindow()


@pytest.mark.skip
def test_GetArcDirection():
    GetArcDirection()


@pytest.mark.skip
def test_GetBkColor():
    GetBkColor()


@pytest.mark.skip
def test_GetBkMode():
    GetBkMode()


@pytest.mark.skip
def test_GetCapture():
    GetCapture()


@pytest.mark.skip
def test_GetCaretPos():
    GetCaretPos()


@pytest.mark.skip
def test_GetClassLong():
    GetClassLong()


@pytest.mark.skip
def test_GetClassName():
    GetClassName()


@pytest.mark.skip
def test_GetClientRect():
    GetClientRect()


@pytest.mark.skip
def test_GetCurrentObject():
    GetCurrentObject()


@pytest.mark.skip
def test_GetCurrentPositionEx():
    GetCurrentPositionEx()


@pytest.mark.skip
def test_GetCursor():
    GetCursor()


@pytest.mark.skip
def test_GetCursorInfo():
    GetCursorInfo()


@pytest.mark.skip
def test_GetCursorPos():
    GetCursorPos()


@pytest.mark.skip
def test_GetDC():
    GetDC()


@pytest.mark.skip
def test_GetDesktopWindow():
    GetDesktopWindow()


@pytest.mark.skip
def test_GetDlgCtrlID():
    GetDlgCtrlID()


@pytest.mark.skip
def test_GetDlgItem():
    GetDlgItem()


@pytest.mark.skip
def test_GetDlgItemInt():
    GetDlgItemInt()


@pytest.mark.skip
def test_GetDlgItemText():
    GetDlgItemText()


@pytest.mark.skip
def test_GetDoubleClickTime():
    GetDoubleClickTime()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetForegroundWindow():
    GetForegroundWindow()


@pytest.mark.skip
def test_GetGraphicsMode():
    GetGraphicsMode()


@pytest.mark.skip
def test_GetIconInfo():
    GetIconInfo()


@pytest.mark.skip
def test_GetLayeredWindowAttributes():
    GetLayeredWindowAttributes()


@pytest.mark.skip
def test_GetLayout():
    GetLayout()


@pytest.mark.skip
def test_GetMapMode():
    GetMapMode()


@pytest.mark.skip
def test_GetMenu():
    GetMenu()


@pytest.mark.skip
def test_GetMenuDefaultItem():
    GetMenuDefaultItem()


@pytest.mark.skip
def test_GetMenuInfo():
    GetMenuInfo()


@pytest.mark.skip
def test_GetMenuItemCount():
    GetMenuItemCount()


@pytest.mark.skip
def test_GetMenuItemID():
    GetMenuItemID()


@pytest.mark.skip
def test_GetMenuItemInfo():
    GetMenuItemInfo()


@pytest.mark.skip
def test_GetMenuItemRect():
    GetMenuItemRect()


@pytest.mark.skip
def test_GetMenuState():
    GetMenuState()


@pytest.mark.skip
def test_GetMessage():
    GetMessage()


@pytest.mark.skip
def test_GetMiterLimit():
    GetMiterLimit()


@pytest.mark.skip
def test_GetNextDlgGroupItem():
    GetNextDlgGroupItem()


@pytest.mark.skip
def test_GetNextDlgTabItem():
    GetNextDlgTabItem()


@pytest.mark.skip
def test_GetObject():
    GetObject()


@pytest.mark.skip
def test_GetObjectType():
    GetObjectType()


@pytest.mark.skip
def test_GetOpenFileName():
    GetOpenFileName()


@pytest.mark.skip
def test_GetOpenFileNameW():
    GetOpenFileNameW()


@pytest.mark.skip
def test_GetParent():
    GetParent()


@pytest.mark.skip
def test_GetPath():
    GetPath()


@pytest.mark.skip
def test_GetPixel():
    GetPixel()


@pytest.mark.skip
def test_GetPolyFillMode():
    GetPolyFillMode()


@pytest.mark.skip
def test_GetROP2():
    GetROP2()


@pytest.mark.skip
def test_GetRgnBox():
    GetRgnBox()


@pytest.mark.skip
def test_GetSaveFileNameW():
    GetSaveFileNameW()


@pytest.mark.skip
def test_GetScrollInfo():
    GetScrollInfo()


@pytest.mark.skip
def test_GetStockObject():
    GetStockObject()


@pytest.mark.skip
def test_GetStretchBltMode():
    GetStretchBltMode()


@pytest.mark.skip
def test_GetSubMenu():
    GetSubMenu()


@pytest.mark.skip
def test_GetSysColor():
    GetSysColor()


@pytest.mark.skip
def test_GetSysColorBrush():
    GetSysColorBrush()


@pytest.mark.skip
def test_GetSystemMenu():
    GetSystemMenu()


@pytest.mark.skip
def test_GetTextAlign():
    GetTextAlign()


@pytest.mark.skip
def test_GetTextCharacterExtra():
    GetTextCharacterExtra()


@pytest.mark.skip
def test_GetTextColor():
    GetTextColor()


@pytest.mark.skip
def test_GetTextExtentPoint32():
    GetTextExtentPoint32()


@pytest.mark.skip
def test_GetTextFace():
    GetTextFace()


@pytest.mark.skip
def test_GetTextMetrics():
    GetTextMetrics()


@pytest.mark.skip
def test_GetUpdateRgn():
    GetUpdateRgn()


@pytest.mark.skip
def test_GetViewportExtEx():
    GetViewportExtEx()


@pytest.mark.skip
def test_GetViewportOrgEx():
    GetViewportOrgEx()


@pytest.mark.skip
def test_GetWindow():
    GetWindow()


@pytest.mark.skip
def test_GetWindowDC():
    GetWindowDC()


@pytest.mark.skip
def test_GetWindowExtEx():
    GetWindowExtEx()


@pytest.mark.skip
def test_GetWindowLong():
    GetWindowLong()


@pytest.mark.skip
def test_GetWindowOrgEx():
    GetWindowOrgEx()


@pytest.mark.skip
def test_GetWindowPlacement():
    GetWindowPlacement()


@pytest.mark.skip
def test_GetWindowRect():
    GetWindowRect()


@pytest.mark.skip
def test_GetWindowRgn():
    GetWindowRgn()


@pytest.mark.skip
def test_GetWindowRgnBox():
    GetWindowRgnBox()


@pytest.mark.skip
def test_GetWindowText():
    GetWindowText()


@pytest.mark.skip
def test_GetWorldTransform():
    GetWorldTransform()


@pytest.mark.skip
def test_GradientFill():
    GradientFill()


@pytest.mark.skip
def test_HideCaret():
    HideCaret()


@pytest.mark.skip
def test_ImageList_Add():
    ImageList_Add()


@pytest.mark.skip
def test_ImageList_Create():
    ImageList_Create()


@pytest.mark.skip
def test_ImageList_Destroy():
    ImageList_Destroy()


@pytest.mark.skip
def test_ImageList_Draw():
    ImageList_Draw()


@pytest.mark.skip
def test_ImageList_DrawEx():
    ImageList_DrawEx()


@pytest.mark.skip
def test_ImageList_GetIcon():
    ImageList_GetIcon()


@pytest.mark.skip
def test_ImageList_GetImageCount():
    ImageList_GetImageCount()


@pytest.mark.skip
def test_ImageList_LoadBitmap():
    ImageList_LoadBitmap()


@pytest.mark.skip
def test_ImageList_LoadImage():
    ImageList_LoadImage()


@pytest.mark.skip
def test_ImageList_Remove():
    ImageList_Remove()


@pytest.mark.skip
def test_ImageList_Replace():
    ImageList_Replace()


@pytest.mark.skip
def test_ImageList_ReplaceIcon():
    ImageList_ReplaceIcon()


@pytest.mark.skip
def test_ImageList_SetBkColor():
    ImageList_SetBkColor()


@pytest.mark.skip
def test_ImageList_SetOverlayImage():
    ImageList_SetOverlayImage()


@pytest.mark.skip
def test_InitCommonControls():
    InitCommonControls()


@pytest.mark.skip
def test_InitCommonControlsEx():
    InitCommonControlsEx()


@pytest.mark.skip
def test_InsertMenu():
    InsertMenu()


@pytest.mark.skip
def test_InsertMenuItem():
    InsertMenuItem()


@pytest.mark.skip
def test_InvalidateRect():
    InvalidateRect()


@pytest.mark.skip
def test_InvalidateRgn():
    InvalidateRgn()


@pytest.mark.skip
def test_InvertRect():
    InvertRect()


@pytest.mark.skip
def test_InvertRgn():
    InvertRgn()


@pytest.mark.skip
def test_IsChild():
    IsChild()


@pytest.mark.skip
def test_IsIconic():
    IsIconic()


@pytest.mark.skip
def test_IsWindow():
    IsWindow()


@pytest.mark.skip
def test_IsWindowEnabled():
    IsWindowEnabled()


@pytest.mark.skip
def test_IsWindowVisible():
    IsWindowVisible()


@pytest.mark.skip
def test_LOGFONT():
    LOGFONT()


@pytest.mark.skip
def test_LineTo():
    LineTo()


@pytest.mark.skip
def test_ListView_SortItems():
    ListView_SortItems()


@pytest.mark.skip
def test_ListView_SortItemsEx():
    ListView_SortItemsEx()


@pytest.mark.skip
def test_LoadCursor():
    LoadCursor()


@pytest.mark.skip
def test_LoadIcon():
    LoadIcon()


@pytest.mark.skip
def test_LoadImage():
    LoadImage()


@pytest.mark.skip
def test_LoadMenu():
    LoadMenu()


@pytest.mark.skip
def test_MaskBlt():
    MaskBlt()


@pytest.mark.skip
def test_MessageBeep():
    MessageBeep()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_ModifyMenu():
    ModifyMenu()


@pytest.mark.skip
def test_ModifyWorldTransform():
    ModifyWorldTransform()


@pytest.mark.skip
def test_MoveToEx():
    MoveToEx()


@pytest.mark.skip
def test_MoveWindow():
    MoveWindow()


@pytest.mark.skip
def test_OffsetRgn():
    OffsetRgn()


@pytest.mark.skip
def test_PaintDesktop():
    PaintDesktop()


@pytest.mark.skip
def test_PaintRgn():
    PaintRgn()


@pytest.mark.skip
def test_PatBlt():
    PatBlt()


@pytest.mark.skip
def test_PathToRegion():
    PathToRegion()


@pytest.mark.skip
def test_PeekMessage():
    PeekMessage()


@pytest.mark.skip
def test_Pie():
    Pie()


@pytest.mark.skip
def test_PlgBlt():
    PlgBlt()


@pytest.mark.skip
def test_PolyBezier():
    PolyBezier()


@pytest.mark.skip
def test_PolyBezierTo():
    PolyBezierTo()


@pytest.mark.skip
def test_Polygon():
    Polygon()


@pytest.mark.skip
def test_Polyline():
    Polyline()


@pytest.mark.skip
def test_PolylineTo():
    PolylineTo()


@pytest.mark.skip
def test_PostMessage():
    PostMessage()


@pytest.mark.skip
def test_PostQuitMessage():
    PostQuitMessage()


@pytest.mark.skip
def test_PostThreadMessage():
    PostThreadMessage()


@pytest.mark.skip
def test_PtInRect():
    PtInRect()


@pytest.mark.skip
def test_PtInRegion():
    PtInRegion()


@pytest.mark.skip
def test_PumpMessages():
    PumpMessages()


@pytest.mark.skip
def test_PumpWaitingMessages():
    PumpWaitingMessages()


@pytest.mark.skip
def test_PyGetArraySignedLong():
    PyGetArraySignedLong()


@pytest.mark.skip
def test_PyGetBufferAddressAndLen():
    PyGetBufferAddressAndLen()


@pytest.mark.skip
def test_PyGetMemory():
    PyGetMemory()


@pytest.mark.skip
def test_PyGetString():
    PyGetString()


@pytest.mark.skip
def test_PySetMemory():
    PySetMemory()


@pytest.mark.skip
def test_PySetString():
    PySetString()


@pytest.mark.skip
def test_RectInRegion():
    RectInRegion()


@pytest.mark.skip
def test_Rectangle():
    Rectangle()


@pytest.mark.skip
def test_RedrawWindow():
    RedrawWindow()


@pytest.mark.skip
def test_RegisterClass():
    RegisterClass()


@pytest.mark.skip
def test_RegisterDeviceNotification():
    RegisterDeviceNotification()


@pytest.mark.skip
def test_RegisterWindowMessage():
    RegisterWindowMessage()


@pytest.mark.skip
def test_ReleaseCapture():
    ReleaseCapture()


@pytest.mark.skip
def test_ReleaseDC():
    ReleaseDC()


@pytest.mark.skip
def test_RemoveMenu():
    RemoveMenu()


@pytest.mark.skip
def test_ReplyMessage():
    ReplyMessage()


@pytest.mark.skip
def test_RestoreDC():
    RestoreDC()


@pytest.mark.skip
def test_RoundRect():
    RoundRect()


@pytest.mark.skip
def test_SaveDC():
    SaveDC()


@pytest.mark.skip
def test_ScreenToClient():
    ScreenToClient()


@pytest.mark.skip
def test_ScrollWindowEx():
    ScrollWindowEx()


@pytest.mark.skip
def test_SelectObject():
    SelectObject()


@pytest.mark.skip
def test_SendMessage():
    SendMessage()


@pytest.mark.skip
def test_SendMessageTimeout():
    SendMessageTimeout()


@pytest.mark.skip
def test_SetActiveWindow():
    SetActiveWindow()


@pytest.mark.skip
def test_SetArcDirection():
    SetArcDirection()


@pytest.mark.skip
def test_SetBkColor():
    SetBkColor()


@pytest.mark.skip
def test_SetBkMode():
    SetBkMode()


@pytest.mark.skip
def test_SetCapture():
    SetCapture()


@pytest.mark.skip
def test_SetCaretPos():
    SetCaretPos()


@pytest.mark.skip
def test_SetCursor():
    SetCursor()


@pytest.mark.skip
def test_SetDlgItemInt():
    SetDlgItemInt()


@pytest.mark.skip
def test_SetDlgItemText():
    SetDlgItemText()


@pytest.mark.skip
def test_SetDoubleClickTime():
    SetDoubleClickTime()


@pytest.mark.skip
def test_SetFocus():
    SetFocus()


@pytest.mark.skip
def test_SetForegroundWindow():
    SetForegroundWindow()


@pytest.mark.skip
def test_SetGraphicsMode():
    SetGraphicsMode()


@pytest.mark.skip
def test_SetLayeredWindowAttributes():
    SetLayeredWindowAttributes()


@pytest.mark.skip
def test_SetLayout():
    SetLayout()


@pytest.mark.skip
def test_SetMapMode():
    SetMapMode()


@pytest.mark.skip
def test_SetMenu():
    SetMenu()


@pytest.mark.skip
def test_SetMenuDefaultItem():
    SetMenuDefaultItem()


@pytest.mark.skip
def test_SetMenuInfo():
    SetMenuInfo()


@pytest.mark.skip
def test_SetMenuItemBitmaps():
    SetMenuItemBitmaps()


@pytest.mark.skip
def test_SetMenuItemInfo():
    SetMenuItemInfo()


@pytest.mark.skip
def test_SetMiterLimit():
    SetMiterLimit()


@pytest.mark.skip
def test_SetParent():
    SetParent()


@pytest.mark.skip
def test_SetPixel():
    SetPixel()


@pytest.mark.skip
def test_SetPixelV():
    SetPixelV()


@pytest.mark.skip
def test_SetPolyFillMode():
    SetPolyFillMode()


@pytest.mark.skip
def test_SetROP2():
    SetROP2()


@pytest.mark.skip
def test_SetRectRgn():
    SetRectRgn()


@pytest.mark.skip
def test_SetScrollInfo():
    SetScrollInfo()


@pytest.mark.skip
def test_SetStretchBltMode():
    SetStretchBltMode()


@pytest.mark.skip
def test_SetTextAlign():
    SetTextAlign()


@pytest.mark.skip
def test_SetTextCharacterExtra():
    SetTextCharacterExtra()


@pytest.mark.skip
def test_SetTextColor():
    SetTextColor()


@pytest.mark.skip
def test_SetViewportExtEx():
    SetViewportExtEx()


@pytest.mark.skip
def test_SetViewportOrgEx():
    SetViewportOrgEx()


@pytest.mark.skip
def test_SetWindowExtEx():
    SetWindowExtEx()


@pytest.mark.skip
def test_SetWindowLong():
    SetWindowLong()


@pytest.mark.skip
def test_SetWindowOrgEx():
    SetWindowOrgEx()


@pytest.mark.skip
def test_SetWindowPlacement():
    SetWindowPlacement()


@pytest.mark.skip
def test_SetWindowPos():
    SetWindowPos()


@pytest.mark.skip
def test_SetWindowRgn():
    SetWindowRgn()


@pytest.mark.skip
def test_SetWindowText():
    SetWindowText()


@pytest.mark.skip
def test_SetWorldTransform():
    SetWorldTransform()


@pytest.mark.skip
def test_Shell_NotifyIcon():
    Shell_NotifyIcon()


@pytest.mark.skip
def test_ShowCaret():
    ShowCaret()


@pytest.mark.skip
def test_ShowWindow():
    ShowWindow()


@pytest.mark.skip
def test_StretchBlt():
    StretchBlt()


@pytest.mark.skip
def test_StrokeAndFillPath():
    StrokeAndFillPath()


@pytest.mark.skip
def test_StrokePath():
    StrokePath()


@pytest.mark.skip
def test_SystemParametersInfo():
    SystemParametersInfo()


@pytest.mark.skip
def test_TrackPopupMenu():
    TrackPopupMenu()


@pytest.mark.skip
def test_TranslateAccelerator():
    TranslateAccelerator()


@pytest.mark.skip
def test_TranslateMessage():
    TranslateMessage()


@pytest.mark.skip
def test_TransparentBlt():
    TransparentBlt()


@pytest.mark.skip
def test_UnregisterClass():
    UnregisterClass()


@pytest.mark.skip
def test_UnregisterDeviceNotification():
    UnregisterDeviceNotification()


@pytest.mark.skip
def test_UpdateLayeredWindow():
    UpdateLayeredWindow()


@pytest.mark.skip
def test_UpdateWindow():
    UpdateWindow()


@pytest.mark.skip
def test_ValidateRgn():
    ValidateRgn()


@pytest.mark.skip
def test_WaitMessage():
    WaitMessage()


@pytest.mark.skip
def test_WidenPath():
    WidenPath()


@pytest.mark.skip
def test_WindowFromDC():
    WindowFromDC()


@pytest.mark.skip
def test_WindowFromPoint():
    WindowFromPoint()


@pytest.mark.skip
def test_TrackMouseEvent():
    TrackMouseEvent()


@pytest.mark.skip
def test_set_logger():
    set_logger()
