import pytest
import pytest
import pytest
import pytest
import pytest
from axcontrol import *
@pytest.mark.xfail
def test_OleCreate():
    OleCreate()     



@pytest.mark.xfail
def test_OleLoadPicture():
    OleLoadPicture()     



@pytest.mark.xfail
def test_OleLoadPicturePath():
    OleLoadPicturePath()     



@pytest.mark.xfail
def test_OleSetContainedObject():
    OleSetContainedObject()     



@pytest.mark.xfail
def test_OleTranslateAccelerator():
    OleTranslateAccelerator()     


