import pytest
import pytest
import pytest
from internet import *
@pytest.mark.xfail
def test_CoInternetCreateSecurityManager():
    CoInternetCreateSecurityManager()     



@pytest.mark.xfail
def test_CoInternetIsFeatureEnabled():
    CoInternetIsFeatureEnabled()     



@pytest.mark.xfail
def test_CoInternetSetFeatureEnabled():
    CoInternetSetFeatureEnabled()     


