import pytest
import pytest
import pytest
import pytest
import pytest
from perfmon import *
@pytest.mark.xfail
def test_CounterDefinition():
    CounterDefinition()     



@pytest.mark.xfail
def test_LoadPerfCounterTextStrings():
    LoadPerfCounterTextStrings()     



@pytest.mark.xfail
def test_ObjectType():
    ObjectType()     



@pytest.mark.xfail
def test_PerfMonManager():
    PerfMonManager()     



@pytest.mark.xfail
def test_UnloadPerfCounterTextStrings():
    UnloadPerfCounterTextStrings()     


