import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32net import *
@pytest.mark.xfail
def test_NetFileClose():
    NetFileClose()     



@pytest.mark.xfail
def test_NetFileEnum():
    NetFileEnum()     



@pytest.mark.xfail
def test_NetFileGetInfo():
    NetFileGetInfo()     



@pytest.mark.xfail
def test_NetGetAnyDCName():
    NetGetAnyDCName()     



@pytest.mark.xfail
def test_NetGetDCName():
    NetGetDCName()     



def test_NetGetJoinInformation():
    NetGetJoinInformation()     



@pytest.mark.xfail
def test_NetGroupAdd():
    NetGroupAdd()     



@pytest.mark.xfail
def test_NetGroupAdd():
    NetGroupAdd()     



@pytest.mark.xfail
def test_NetGroupAddUser():
    NetGroupAddUser()     



@pytest.mark.xfail
def test_NetGroupDel():
    NetGroupDel()     



@pytest.mark.xfail
def test_NetGroupDel():
    NetGroupDel()     



@pytest.mark.xfail
def test_NetGroupDelUser():
    NetGroupDelUser()     



@pytest.mark.xfail
def test_NetGroupEnum():
    NetGroupEnum()     



@pytest.mark.xfail
def test_NetGroupEnum():
    NetGroupEnum()     



@pytest.mark.xfail
def test_NetGroupGetInfo():
    NetGroupGetInfo()     



@pytest.mark.xfail
def test_NetGroupGetInfo():
    NetGroupGetInfo()     



@pytest.mark.xfail
def test_NetGroupGetUsers():
    NetGroupGetUsers()     



@pytest.mark.xfail
def test_NetGroupSetInfo():
    NetGroupSetInfo()     



@pytest.mark.xfail
def test_NetGroupSetInfo():
    NetGroupSetInfo()     



@pytest.mark.xfail
def test_NetGroupSetUsers():
    NetGroupSetUsers()     



@pytest.mark.xfail
def test_NetLocalGroupAddMembers():
    NetLocalGroupAddMembers()     



@pytest.mark.xfail
def test_NetLocalGroupDelMembers():
    NetLocalGroupDelMembers()     



@pytest.mark.xfail
def test_NetLocalGroupGetMembers():
    NetLocalGroupGetMembers()     



@pytest.mark.xfail
def test_NetLocalGroupSetMembers():
    NetLocalGroupSetMembers()     



@pytest.mark.xfail
def test_NetMessageBufferSend():
    NetMessageBufferSend()     



@pytest.mark.xfail
def test_NetMessageNameAdd():
    NetMessageNameAdd()     



@pytest.mark.xfail
def test_NetMessageNameDel():
    NetMessageNameDel()     



@pytest.mark.xfail
def test_NetMessageNameEnum():
    NetMessageNameEnum()     



@pytest.mark.xfail
def test_NetServerComputerNameAdd():
    NetServerComputerNameAdd()     



@pytest.mark.xfail
def test_NetServerComputerNameDel():
    NetServerComputerNameDel()     



@pytest.mark.xfail
def test_NetServerDiskEnum():
    NetServerDiskEnum()     



@pytest.mark.xfail
def test_NetServerEnum():
    NetServerEnum()     



@pytest.mark.xfail
def test_NetServerGetInfo():
    NetServerGetInfo()     



@pytest.mark.xfail
def test_NetServerSetInfo():
    NetServerSetInfo()     



@pytest.mark.xfail
def test_NetSessionDel():
    NetSessionDel()     



@pytest.mark.xfail
def test_NetSessionEnum():
    NetSessionEnum()     



@pytest.mark.xfail
def test_NetSessionGetInfo():
    NetSessionGetInfo()     



@pytest.mark.xfail
def test_NetShareAdd():
    NetShareAdd()     



@pytest.mark.xfail
def test_NetShareCheck():
    NetShareCheck()     



@pytest.mark.xfail
def test_NetShareDel():
    NetShareDel()     



@pytest.mark.xfail
def test_NetShareEnum():
    NetShareEnum()     



@pytest.mark.xfail
def test_NetShareGetInfo():
    NetShareGetInfo()     



@pytest.mark.xfail
def test_NetShareSetInfo():
    NetShareSetInfo()     



@pytest.mark.xfail
def test_NetStatisticsGet():
    NetStatisticsGet()     



@pytest.mark.xfail
def test_NetUseAdd():
    NetUseAdd()     



@pytest.mark.xfail
def test_NetUseDel():
    NetUseDel()     



@pytest.mark.xfail
def test_NetUseEnum():
    NetUseEnum()     



@pytest.mark.xfail
def test_NetUseGetInfo():
    NetUseGetInfo()     



@pytest.mark.xfail
def test_NetUserAdd():
    NetUserAdd()     



@pytest.mark.xfail
def test_NetUserChangePassword():
    NetUserChangePassword()     



@pytest.mark.xfail
def test_NetUserDel():
    NetUserDel()     



@pytest.mark.xfail
def test_NetUserEnum():
    NetUserEnum()     



@pytest.mark.xfail
def test_NetUserGetGroups():
    NetUserGetGroups()     



@pytest.mark.xfail
def test_NetUserGetInfo():
    NetUserGetInfo()     



@pytest.mark.xfail
def test_NetUserGetLocalGroups():
    NetUserGetLocalGroups()     



@pytest.mark.xfail
def test_NetUserModalsGet():
    NetUserModalsGet()     



@pytest.mark.xfail
def test_NetUserModalsSet():
    NetUserModalsSet()     



@pytest.mark.xfail
def test_NetUserSetInfo():
    NetUserSetInfo()     



@pytest.mark.xfail
def test_NetValidateName():
    NetValidateName()     



@pytest.mark.xfail
def test_NetValidatePasswordPolicy():
    NetValidatePasswordPolicy()     



@pytest.mark.xfail
def test_NetWkstaGetInfo():
    NetWkstaGetInfo()     



@pytest.mark.xfail
def test_NetWkstaSetInfo():
    NetWkstaSetInfo()     



@pytest.mark.xfail
def test_NetWkstaTransportAdd():
    NetWkstaTransportAdd()     



@pytest.mark.xfail
def test_NetWkstaTransportDel():
    NetWkstaTransportDel()     



@pytest.mark.xfail
def test_NetWkstaTransportEnum():
    NetWkstaTransportEnum()     



@pytest.mark.xfail
def test_NetWkstaUserEnum():
    NetWkstaUserEnum()     


