from exchange import *
def test_HrCreateDirEntryIdEx():
    HrCreateDirEntryIdEx()     



def test_HrCreateProfileName():
    HrCreateProfileName()     



def test_HrFindExchangeGlobalAddressList():
    HrFindExchangeGlobalAddressList()     



def test_HrGetExchangeStatus():
    HrGetExchangeStatus()     



def test_HrGetMailboxDN():
    HrGetMailboxDN()     



def test_HrGetServerDN():
    HrGetServerDN()     



def test_HrMAPIFindDefaultMsgStore():
    HrMAPIFindDefaultMsgStore()     



def test_HrMAPIFindFolder():
    HrMAPIFindFolder()     



def test_HrMAPIFindFolderEx():
    HrMAPIFindFolderEx()     



def test_HrMAPIFindIPMSubtree():
    HrMAPIFindIPMSubtree()     



def test_HrMAPIFindInbox():
    HrMAPIFindInbox()     



def test_HrMAPIFindStore():
    HrMAPIFindStore()     



def test_HrMAPIFindSubfolderEx():
    HrMAPIFindSubfolderEx()     



def test_HrMAPIOpenFolderEx():
    HrMAPIOpenFolderEx()     



def test_HrMAPISetPropBoolean():
    HrMAPISetPropBoolean()     



def test_HrMAPISetPropLong():
    HrMAPISetPropLong()     



def test_HrMailboxLogoff():
    HrMailboxLogoff()     



def test_HrMailboxLogon():
    HrMailboxLogon()     



def test_HrOpenExchangePrivateStore():
    HrOpenExchangePrivateStore()     



def test_HrOpenExchangePublicFolders():
    HrOpenExchangePublicFolders()     



def test_HrOpenExchangePublicStore():
    HrOpenExchangePublicStore()     



def test_HrOpenSessionObject():
    HrOpenSessionObject()     



def test_HrOpenSiteContainer():
    HrOpenSiteContainer()     



def test_HrOpenSiteContainerAddressing():
    HrOpenSiteContainerAddressing()     


