import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32job import *
@pytest.mark.xfail
def test_AssignProcessToJobObject():
    AssignProcessToJobObject()     



@pytest.mark.xfail
def test_CreateJobObject():
    CreateJobObject()     



@pytest.mark.xfail
def test_IsProcessInJob():
    IsProcessInJob()     



@pytest.mark.xfail
def test_OpenJobObject():
    OpenJobObject()     



@pytest.mark.xfail
def test_QueryInformationJobObject():
    QueryInformationJobObject()     



@pytest.mark.xfail
def test_SetInformationJobObject():
    SetInformationJobObject()     



@pytest.mark.xfail
def test_TerminateJobObject():
    TerminateJobObject()     



@pytest.mark.xfail
def test_UserHandleGrantAccess():
    UserHandleGrantAccess()     


