import pytest

# from win32ui import *


@pytest.mark.skip
def test_AddToRecentFileList():
    AddToRecentFileList()


@pytest.mark.skip
def test_ComparePath():
    ComparePath()


@pytest.mark.skip
def test_CreateBitmap():
    CreateBitmap()


@pytest.mark.skip
def test_CreateBitmapFromHandle():
    CreateBitmapFromHandle()


@pytest.mark.skip
def test_CreateBrush():
    CreateBrush()


@pytest.mark.skip
def test_CreateButton():
    CreateButton()


@pytest.mark.skip
def test_CreateColorDialog():
    CreateColorDialog()


@pytest.mark.skip
def test_CreateControl():
    CreateControl()


@pytest.mark.skip
def test_CreateControlBar():
    CreateControlBar()


@pytest.mark.skip
def test_CreateCtrlView():
    CreateCtrlView()


@pytest.mark.skip
def test_CreateDC():
    CreateDC()


@pytest.mark.skip
def test_CreateDCFromHandle():
    CreateDCFromHandle()


@pytest.mark.skip
def test_CreateDebuggerThread():
    CreateDebuggerThread()


@pytest.mark.skip
def test_CreateDialog():
    CreateDialog()


@pytest.mark.skip
def test_CreateDialogBar():
    CreateDialogBar()


@pytest.mark.skip
def test_CreateDialogIndirect():
    CreateDialogIndirect()


@pytest.mark.skip
def test_CreateDocTemplate():
    CreateDocTemplate()


@pytest.mark.skip
def test_CreateEdit():
    CreateEdit()


@pytest.mark.skip
def test_CreateEditView():
    CreateEditView()


@pytest.mark.skip
def test_CreateFileDialog():
    CreateFileDialog()


@pytest.mark.skip
def test_CreateFont():
    CreateFont()


@pytest.mark.skip
def test_CreateFontDialog():
    CreateFontDialog()


@pytest.mark.skip
def test_CreateFormView():
    CreateFormView()


@pytest.mark.skip
def test_CreateFrame():
    CreateFrame()


@pytest.mark.skip
def test_CreateImageList():
    CreateImageList()


@pytest.mark.skip
def test_CreateListCtrl():
    CreateListCtrl()


@pytest.mark.skip
def test_CreateListView():
    CreateListView()


@pytest.mark.skip
def test_CreateMDIChild():
    CreateMDIChild()


@pytest.mark.skip
def test_CreateMDIFrame():
    CreateMDIFrame()


@pytest.mark.skip
def test_CreateMenu():
    CreateMenu()


@pytest.mark.skip
def test_CreatePalette():
    CreatePalette()


@pytest.mark.skip
def test_CreatePen():
    CreatePen()


@pytest.mark.skip
def test_CreatePopupMenu():
    CreatePopupMenu()


@pytest.mark.skip
def test_CreatePrintDialog():
    CreatePrintDialog()


@pytest.mark.skip
def test_CreateProgressCtrl():
    CreateProgressCtrl()


@pytest.mark.skip
def test_CreatePropertyPage():
    CreatePropertyPage()


@pytest.mark.skip
def test_CreatePropertyPageIndirect():
    CreatePropertyPageIndirect()


@pytest.mark.skip
def test_CreatePropertySheet():
    CreatePropertySheet()


@pytest.mark.skip
def test_CreateRectRgn():
    CreateRectRgn()


@pytest.mark.skip
def test_CreateRgn():
    CreateRgn()


@pytest.mark.skip
def test_CreateRichEditCtrl():
    CreateRichEditCtrl()


@pytest.mark.skip
def test_CreateRichEditDocTemplate():
    CreateRichEditDocTemplate()


@pytest.mark.skip
def test_CreateRichEditView():
    CreateRichEditView()


@pytest.mark.skip
def test_CreateSliderCtrl():
    CreateSliderCtrl()


@pytest.mark.skip
def test_CreateSplitter():
    CreateSplitter()


@pytest.mark.skip
def test_CreateStatusBar():
    CreateStatusBar()


@pytest.mark.skip
def test_CreateStatusBarCtrl():
    CreateStatusBarCtrl()


@pytest.mark.skip
def test_CreateThread():
    CreateThread()


@pytest.mark.skip
def test_CreateToolBar():
    CreateToolBar()


@pytest.mark.skip
def test_CreateToolBarCtrl():
    CreateToolBarCtrl()


@pytest.mark.skip
def test_CreateToolTipCtrl():
    CreateToolTipCtrl()


@pytest.mark.skip
def test_CreateTreeCtrl():
    CreateTreeCtrl()


@pytest.mark.skip
def test_CreateTreeView():
    CreateTreeView()


@pytest.mark.skip
def test_CreateView():
    CreateView()


@pytest.mark.skip
def test_CreateWindowFromHandle():
    CreateWindowFromHandle()


@pytest.mark.skip
def test_CreateWnd():
    CreateWnd()


@pytest.mark.skip
def test_DestroyDebuggerThread():
    DestroyDebuggerThread()


@pytest.mark.skip
def test_DisplayTraceback():
    DisplayTraceback()


@pytest.mark.skip
def test_DoWaitCursor():
    DoWaitCursor()


@pytest.mark.skip
def test_Enable3dControls():
    Enable3dControls()


@pytest.mark.skip
def test_EnableControlContainer():
    EnableControlContainer()


@pytest.mark.skip
def test_FindWindow():
    FindWindow()


@pytest.mark.skip
def test_FindWindowEx():
    FindWindowEx()


@pytest.mark.skip
def test_FullPath():
    FullPath()


@pytest.mark.skip
def test_GetActiveWindow():
    GetActiveWindow()


@pytest.mark.skip
def test_GetApp():
    GetApp()


@pytest.mark.skip
def test_GetAppName():
    GetAppName()


@pytest.mark.skip
def test_GetAppRegistryKey():
    GetAppRegistryKey()


@pytest.mark.skip
def test_GetBytes():
    GetBytes()


@pytest.mark.skip
def test_GetCommandLine():
    GetCommandLine()


@pytest.mark.skip
def test_GetDeviceCaps():
    GetDeviceCaps()


@pytest.mark.skip
def test_GetFileTitle():
    GetFileTitle()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetForegroundWindow():
    GetForegroundWindow()


@pytest.mark.skip
def test_GetHalftoneBrush():
    GetHalftoneBrush()


@pytest.mark.skip
def test_GetInitialStateRequest():
    GetInitialStateRequest()


@pytest.mark.skip
def test_GetMainFrame():
    GetMainFrame()


@pytest.mark.skip
def test_GetName():
    GetName()


@pytest.mark.skip
def test_GetProfileFileName():
    GetProfileFileName()


@pytest.mark.skip
def test_GetProfileVal():
    GetProfileVal()


@pytest.mark.skip
def test_GetRecentFileList():
    GetRecentFileList()


@pytest.mark.skip
def test_GetResource():
    GetResource()


@pytest.mark.skip
def test_GetThread():
    GetThread()


@pytest.mark.skip
def test_GetType():
    GetType()


@pytest.mark.skip
def test_InitRichEdit():
    InitRichEdit()


@pytest.mark.skip
def test_InstallCallbackCaller():
    InstallCallbackCaller()


@pytest.mark.skip
def test_IsDebug():
    IsDebug()


@pytest.mark.skip
def test_IsObject():
    IsObject()


@pytest.mark.skip
def test_IsWin32s():
    IsWin32s()


@pytest.mark.skip
def test_LoadDialogResource():
    LoadDialogResource()


@pytest.mark.skip
def test_LoadLibrary():
    LoadLibrary()


@pytest.mark.skip
def test_LoadMenu():
    LoadMenu()


@pytest.mark.skip
def test_LoadStdProfileSettings():
    LoadStdProfileSettings()


@pytest.mark.skip
def test_LoadString():
    LoadString()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_OutputDebugString():
    OutputDebugString()


@pytest.mark.skip
def test_PrintTraceback():
    PrintTraceback()


@pytest.mark.skip
def test_PumpWaitingMessages():
    PumpWaitingMessages()


@pytest.mark.skip
def test_RegisterWndClass():
    RegisterWndClass()


@pytest.mark.skip
def test_RemoveRecentFile():
    RemoveRecentFile()


@pytest.mark.skip
def test_SetAppHelpPath():
    SetAppHelpPath()


@pytest.mark.skip
def test_SetAppName():
    SetAppName()


@pytest.mark.skip
def test_SetCurrentInstanceHandle():
    SetCurrentInstanceHandle()


@pytest.mark.skip
def test_SetCurrentResourceHandle():
    SetCurrentResourceHandle()


@pytest.mark.skip
def test_SetDialogBkColor():
    SetDialogBkColor()


@pytest.mark.skip
def test_SetProfileFileName():
    SetProfileFileName()


@pytest.mark.skip
def test_SetRegistryKey():
    SetRegistryKey()


@pytest.mark.skip
def test_SetResource():
    SetResource()


@pytest.mark.skip
def test_SetStatusText():
    SetStatusText()


@pytest.mark.skip
def test_StartDebuggerPump():
    StartDebuggerPump()


@pytest.mark.skip
def test_StopDebuggerPump():
    StopDebuggerPump()


@pytest.mark.skip
def test_TranslateMessage():
    TranslateMessage()


@pytest.mark.skip
def test_TranslateVirtualKey():
    TranslateVirtualKey()


@pytest.mark.skip
def test_WinHelp():
    WinHelp()


@pytest.mark.skip
def test_WriteProfileVal():
    WriteProfileVal()
