import pytest

# from win32uiole import *


@pytest.mark.skip
def test_AfxOleInit():
    AfxOleInit()


@pytest.mark.skip
def test_CreateInsertDialog():
    CreateInsertDialog()


@pytest.mark.skip
def test_CreateOleClientItem():
    CreateOleClientItem()


@pytest.mark.skip
def test_CreateOleDocument():
    CreateOleDocument()


@pytest.mark.skip
def test_DaoGetEngine():
    DaoGetEngine()


@pytest.mark.skip
def test_EnableNotRespondingDialog():
    EnableNotRespondingDialog()


@pytest.mark.skip
def test_EnableNotRespondingDialog():
    EnableNotRespondingDialog()


@pytest.mark.skip
def test_GetIDispatchForWindow():
    GetIDispatchForWindow()


@pytest.mark.skip
def test_OleGetUserCtrl():
    OleGetUserCtrl()


@pytest.mark.skip
def test_OleSetUserCtrl():
    OleSetUserCtrl()


@pytest.mark.skip
def test_SetMessagePendingDelay():
    SetMessagePendingDelay()
