import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32cred import *
@pytest.mark.xfail
def test_CredDelete():
    CredDelete()     



@pytest.mark.xfail
def test_CredEnumerate():
    CredEnumerate()     



@pytest.mark.xfail
def test_CredGetTargetInfo():
    CredGetTargetInfo()     



@pytest.mark.xfail
def test_CredIsMarshaledCredential():
    CredIsMarshaledCredential()     



@pytest.mark.xfail
def test_CredMarshalCredential():
    CredMarshalCredential()     



@pytest.mark.xfail
def test_CredRead():
    CredRead()     



@pytest.mark.xfail
def test_CredReadDomainCredentials():
    CredReadDomainCredentials()     



@pytest.mark.xfail
def test_CredRename():
    CredRename()     



@pytest.mark.xfail
def test_CredUICmdLinePromptForCredentials():
    CredUICmdLinePromptForCredentials()     



@pytest.mark.xfail
def test_CredUIConfirmCredentials():
    CredUIConfirmCredentials()     



@pytest.mark.xfail
def test_CredUIParseUserName():
    CredUIParseUserName()     



@pytest.mark.xfail
def test_CredUIPromptForCredentials():
    CredUIPromptForCredentials()     



@pytest.mark.xfail
def test_CredUIReadSSOCredW():
    CredUIReadSSOCredW()     



@pytest.mark.xfail
def test_CredUIStoreSSOCredW():
    CredUIStoreSSOCredW()     



@pytest.mark.xfail
def test_CredUnmarshalCredential():
    CredUnmarshalCredential()     



@pytest.mark.xfail
def test_CredWrite():
    CredWrite()     



@pytest.mark.xfail
def test_CredWriteDomainCredentials():
    CredWriteDomainCredentials()     


