from wincerapi import *
def test_CeCheckPassword():
    CeCheckPassword()     



def test_CeCopyFile():
    CeCopyFile()     



def test_CeCreateDirectory():
    CeCreateDirectory()     



def test_CeCreateFile():
    CeCreateFile()     



def test_CeDeleteFile():
    CeDeleteFile()     



def test_CeGetDesktopDeviceCaps():
    CeGetDesktopDeviceCaps()     



def test_CeGetFileAttributes():
    CeGetFileAttributes()     



def test_CeGetFileSize():
    CeGetFileSize()     



def test_CeGetSpecialFolderPath():
    CeGetSpecialFolderPath()     



def test_CeGetStoreInformation():
    CeGetStoreInformation()     



def test_CeGetSystemInfo():
    CeGetSystemInfo()     



def test_CeGetSystemMetrics():
    CeGetSystemMetrics()     



def test_CeGetSystemPowerStatusEx():
    CeGetSystemPowerStatusEx()     



def test_CeGetTempPath():
    CeGetTempPath()     



def test_CeGetVersionEx():
    CeGetVersionEx()     



def test_CeGlobalMemoryStatus():
    CeGlobalMemoryStatus()     



def test_CeMoveFile():
    CeMoveFile()     



def test_CeRapiInit():
    CeRapiInit()     



def test_CeRapiInitEx():
    CeRapiInitEx()     



def test_CeRapiUninit():
    CeRapiUninit()     



def test_CeReadFile():
    CeReadFile()     



def test_CeRemoveDirectory():
    CeRemoveDirectory()     



def test_CeSHCreateShortcut():
    CeSHCreateShortcut()     



def test_CeSHGetShortcutTarget():
    CeSHGetShortcutTarget()     



def test_CeSetFileAttributes():
    CeSetFileAttributes()     



def test_CreateProcess():
    CreateProcess()     



def test_FindFiles():
    FindFiles()     



def test_WriteFile():
    WriteFile()     


