/*
 *  EDKGUID.H
 *
 *  Microsoft Exchange Messaging Service
 *  Copyright (C) 1986-1996, Microsoft Corporation
 *  
 *  Contains declarations of GUID's for additional interfaces
 *  offered by Microsoft Exchange Messaging Service.
 */

#ifndef EDKGUID_INCLUDED
#define EDKGUID_INCLUDED

DEFINE_GUID(IID_IExchangeManageStore, 0x559d10b0,0xa772,0x11cd,0x9b,0xc8,0x00,0xaa,0x00,0x2f,0xc4,0x5a);
DEFINE_GUID(IID_IExchangeManageStore2,0xb6dca470, 0xff3, 0x11d0, 0xa4, 0x9, 0x0, 0xc0, 0x4f, 0xd7, 0xbd, 0x87);
DEFINE_GUID(IID_IExchangeManageStore3,0x166d9bc2, 0xdb75, 0x44a9, 0x8a, 0x93, 0x9f, 0x3f, 0xfc, 0x99, 0x4d, 0x76) ;
DEFINE_GUID(IID_IExchangeManageStore4,0x2590ff87, 0xc431, 0x4f9c, 0xb1, 0xa8, 0xcd, 0x69, 0xd7, 0x60, 0xcd, 0x10);	// {2590FF87-C431-4f9c-B1A8-CD69D760CD10}
DEFINE_GUID(IID_IExchangeModifyTable, 0x2d734cb0,0x53fd,0x101b,0xb1,0x9d,0x08,0x00,0x2b,0x30,0x56,0xe3);
DEFINE_GUID(IID_IExchangeRuleAction,  0x74bba840,0xc93a,0x11ce,0x95,0x81,0x00,0xaa,0x00,0x57,0x42,0xf7);
DEFINE_GUID(IID_IExchangeFastTransfer, 0xff7db070,0xa88a,0x11cd,0x9b,0xc8,0x00,0xaa,0x00,0x2f,0xc4,0x5a);

DEFINE_GUID(IID_IExchangeExportChanges, 0xa3ea9cc0,0xd1b2,0x11cd,0x80,0xfc,0x00,0xaa,0x00,0x4b,0xba,0x0b);
DEFINE_GUID(IID_IExchangeExportChanges2, 0x387cebe0,0xf53f,0x11cf,0xa4,0x8f,0x00,0xc0,0x4f, 0xd6, 0x55, 0x95);
DEFINE_GUID(IID_IExchangeExportChanges3, 0x702e7f86,0x50a6,0x11d1,0xab,0xd6,0x00,0xa0,0xc9, 0x05, 0x66, 0x0a);
DEFINE_GUID(IID_IExchangeImportHierarchyChanges, 0x85a66cf0,0xd0e0,0x11cd,0x80,0xfc,0x00,0xaa,0x00,0x4b,0xba,0x0b);
DEFINE_GUID(IID_IExchangeImportContentsChanges, 0xf75abfa0,0xd0e0,0x11cd,0x80,0xfc,0x00,0xaa,0x00,0x4b,0xba,0x0b);
DEFINE_GUID(IID_IExchangeImportContentsChanges2, 0x7dfdd720,0xf53f,0x11cf,0xa4,0x8f,0x00,0xc0,0x4f,0xd6,0x55,0x95);
DEFINE_GUID(IID_IExchangeChangeAdvisor, 0x1e300720, 0xa839, 0x11cf, 0xbd, 0xe0, 0x0, 0x0, 0x4c, 0x75, 0x31, 0xe3);
DEFINE_GUID(IID_IExchangeMessageConversion, 0x3532b360,0xd114,0x11cf,0xa8,0x3b, 0x0, 0xc0,0x4f, 0xd6, 0x55, 0x97);

DEFINE_GUID(IID_IExchangeFavorites, 0xcf4f3bc0,0xec66,0x11ce,0xb3,0x1c,0x00,0xaa,0x00,0x57,0x4c,0xc6);
DEFINE_GUID(IID_IExchangeNntpNewsfeed, 0x380f41c0,0x3cdc,0x11d0,0x97,0x92,0x00,0xc0,0x4f,0xd6,0x55,0x1d);

// {1DF85AB7-4D20-4a57-B170-2F062136C1D6}
DEFINE_GUID(IID_IExchangeBadItemCallback, 0x1df85ab7,0x4d20,0x4a57,0xb1,0x70,0x2f,0x06,0x21,0x36,0xc1,0xd6);

// {EF2FB44A-8DAC-4e4e-B1E3-A3B926355617}
DEFINE_GUID(IID_IExchangeMoveUserProgress, 0xef2fb44a,0x8dac,0x4e4e,0xb1,0xe3,0xa3,0xb9,0x26,0x35,0x56,0x17);


/*
	The following interface GUID is the start of a range of IID's
	Each IID specifies a different CPID.  The IID corresponding to
	cpid 932 would be defined by 
		DEFINE_GUID(IID_IExchangeMessageCpid0, 932, 0x1ae9, 0x11cf,	0x84, 0xe0, 0x00, 0xaa, 0x00, 0x6b, 04f, 0xae);  
*/

DEFINE_GUID(IID_IExchangeMessageCpid0, 0x0, 0x1ae9,0x11cf, 0x84, 0xe0, 0x00, 0xaa, 0x00, 0x6b, 0x4f, 0xae);  

#endif  //EDKGUID_INCLUDED
