import pytest

from win32api import *


@pytest.mark.skip
def test_AbortSystemShutdown():
    AbortSystemShutdown()


@pytest.mark.skip
def test_Apply():
    Apply()


@pytest.mark.skip
def test_Beep():
    Beep()


@pytest.mark.skip
def test_BeginUpdateResource():
    BeginUpdateResource()


@pytest.mark.skip
def test_ChangeDisplaySettings():
    ChangeDisplaySettings()


@pytest.mark.skip
def test_ChangeDisplaySettingsEx():
    ChangeDisplaySettingsEx()


@pytest.mark.skip
def test_ClipCursor():
    ClipCursor()


@pytest.mark.skip
def test_CloseHandle():
    CloseHandle()


@pytest.mark.skip
def test_CopyFile():
    CopyFile()


@pytest.mark.skip
def test_DebugBreak():
    DebugBreak()


@pytest.mark.skip
def test_DeleteFile():
    DeleteFile()


@pytest.mark.skip
def test_DragFinish():
    DragFinish()


@pytest.mark.skip
def test_DragQueryFile():
    DragQueryFile()


@pytest.mark.skip
def test_DuplicateHandle():
    DuplicateHandle()


@pytest.mark.skip
def test_EndUpdateResource():
    EndUpdateResource()


@pytest.mark.skip
def test_EnumDisplayDevices():
    EnumDisplayDevices()


@pytest.mark.skip
def test_EnumDisplayMonitors():
    EnumDisplayMonitors()


@pytest.mark.skip
def test_EnumDisplaySettings():
    EnumDisplaySettings()


@pytest.mark.skip
def test_EnumDisplaySettingsEx():
    EnumDisplaySettingsEx()


@pytest.mark.skip
def test_EnumResourceLanguages():
    EnumResourceLanguages()


@pytest.mark.skip
def test_EnumResourceNames():
    EnumResourceNames()


@pytest.mark.skip
def test_EnumResourceTypes():
    EnumResourceTypes()


@pytest.mark.skip
def test_ExitWindows():
    ExitWindows()


@pytest.mark.skip
def test_ExitWindowsEx():
    ExitWindowsEx()


@pytest.mark.skip
def test_ExpandEnvironmentStrings():
    ExpandEnvironmentStrings()


@pytest.mark.skip
def test_FindCloseChangeNotification():
    FindCloseChangeNotification()


@pytest.mark.skip
def test_FindExecutable():
    FindExecutable()


@pytest.mark.skip
def test_FindFiles():
    FindFiles()


@pytest.mark.skip
def test_FindFirstChangeNotification():
    FindFirstChangeNotification()


@pytest.mark.skip
def test_FindNextChangeNotification():
    FindNextChangeNotification()


@pytest.mark.skip
def test_FormatMessage():
    FormatMessage()


@pytest.mark.skip
def test_FormatMessageW():
    FormatMessageW()


@pytest.mark.skip
def test_FreeLibrary():
    FreeLibrary()


@pytest.mark.skip
def test_GenerateConsoleCtrlEvent():
    GenerateConsoleCtrlEvent()


@pytest.mark.skip
def test_GetAsyncKeyState():
    GetAsyncKeyState()


@pytest.mark.skip
def test_GetCommandLine():
    GetCommandLine()


@pytest.mark.skip
def test_GetComputerName():
    GetComputerName()


@pytest.mark.skip
def test_GetComputerNameEx():
    GetComputerNameEx()


@pytest.mark.skip
def test_GetComputerObjectName():
    GetComputerObjectName()


@pytest.mark.skip
def test_GetConsoleTitle():
    GetConsoleTitle()


@pytest.mark.skip
def test_GetCurrentProcess():
    GetCurrentProcess()


@pytest.mark.skip
def test_GetCurrentProcessId():
    GetCurrentProcessId()


@pytest.mark.skip
def test_GetCurrentThread():
    GetCurrentThread()


@pytest.mark.skip
def test_GetCurrentThreadId():
    GetCurrentThreadId()


@pytest.mark.skip
def test_GetCursorPos():
    GetCursorPos()


@pytest.mark.skip
def test_GetDateFormat():
    GetDateFormat()


@pytest.mark.skip
def test_GetDiskFreeSpace():
    GetDiskFreeSpace()


@pytest.mark.skip
def test_GetDiskFreeSpaceEx():
    GetDiskFreeSpaceEx()


@pytest.mark.skip
def test_GetDllDirectory():
    GetDllDirectory()


@pytest.mark.skip
def test_GetDomainName():
    GetDomainName()


@pytest.mark.skip
def test_GetEnvironmentVariable():
    GetEnvironmentVariable()


@pytest.mark.skip
def test_GetFileAttributes():
    GetFileAttributes()


@pytest.mark.skip
def test_GetFileVersionInfo():
    GetFileVersionInfo()


@pytest.mark.skip
def test_GetFocus():
    GetFocus()


@pytest.mark.skip
def test_GetFullPathName():
    GetFullPathName()


@pytest.mark.skip
def test_GetHandleInformation():
    GetHandleInformation()


@pytest.mark.skip
def test_GetKeyState():
    GetKeyState()


@pytest.mark.skip
def test_GetKeyboardLayout():
    GetKeyboardLayout()


@pytest.mark.skip
def test_GetKeyboardLayoutList():
    GetKeyboardLayoutList()


@pytest.mark.skip
def test_GetKeyboardState():
    GetKeyboardState()


@pytest.mark.skip
def test_GetLastError():
    GetLastError()


@pytest.mark.skip
def test_GetLastInputInfo():
    GetLastInputInfo()


@pytest.mark.skip
def test_GetLocalTime():
    GetLocalTime()


@pytest.mark.skip
def test_GetLogicalDriveStrings():
    GetLogicalDriveStrings()


@pytest.mark.skip
def test_GetLogicalDrives():
    GetLogicalDrives()


@pytest.mark.skip
def test_GetLongPathName():
    GetLongPathName()


@pytest.mark.skip
def test_GetLongPathNameW():
    GetLongPathNameW()


@pytest.mark.skip
def test_GetModuleFileName():
    GetModuleFileName()


@pytest.mark.skip
def test_GetModuleFileNameW():
    GetModuleFileNameW()


@pytest.mark.skip
def test_GetModuleHandle():
    GetModuleHandle()


@pytest.mark.skip
def test_GetMonitorInfo():
    GetMonitorInfo()


@pytest.mark.skip
def test_GetNativeSystemInfo():
    GetNativeSystemInfo()


@pytest.mark.skip
def test_GetProcAddress():
    GetProcAddress()


@pytest.mark.skip
def test_GetProfileSection():
    GetProfileSection()


@pytest.mark.skip
def test_GetProfileVal():
    GetProfileVal()


@pytest.mark.skip
def test_GetPwrCapabilities():
    GetPwrCapabilities()


@pytest.mark.skip
def test_GetShortPathName():
    GetShortPathName()


@pytest.mark.skip
def test_GetStdHandle():
    GetStdHandle()


@pytest.mark.skip
def test_GetSysColor():
    GetSysColor()


@pytest.mark.skip
def test_GetSystemdefaultLCID():
    GetSystemdefaultLCID()


@pytest.mark.skip
def test_GetSystemdefaultLangID():
    GetSystemdefaultLangID()


@pytest.mark.skip
def test_GetSystemDirectory():
    GetSystemDirectory()


@pytest.mark.skip
def test_GetSystemFileCacheSize():
    GetSystemFileCacheSize()


@pytest.mark.skip
def test_GetSystemInfo():
    GetSystemInfo()


@pytest.mark.skip
def test_GetSystemMetrics():
    GetSystemMetrics()


@pytest.mark.skip
def test_GetSystemTime():
    GetSystemTime()


@pytest.mark.skip
def test_GetTempFileName():
    GetTempFileName()


@pytest.mark.skip
def test_GetTempPath():
    GetTempPath()


@pytest.mark.skip
def test_GetThreadLocale():
    GetThreadLocale()


@pytest.mark.skip
def test_GetTickCount():
    GetTickCount()


@pytest.mark.skip
def test_GetTimeFormat():
    GetTimeFormat()


@pytest.mark.skip
def test_GetTimeZoneInformation():
    GetTimeZoneInformation()


@pytest.mark.skip
def test_GetUserdefaultLCID():
    GetUserdefaultLCID()


@pytest.mark.skip
def test_GetUserdefaultLangID():
    GetUserdefaultLangID()


@pytest.mark.skip
def test_GetUserName():
    GetUserName()


@pytest.mark.skip
def test_GetUserNameEx():
    GetUserNameEx()


@pytest.mark.skip
def test_GetVersion():
    GetVersion()


@pytest.mark.skip
def test_GetVersionEx():
    GetVersionEx()


@pytest.mark.skip
def test_GetVolumeInformation():
    GetVolumeInformation()


@pytest.mark.skip
def test_GetWindowLong():
    GetWindowLong()


@pytest.mark.skip
def test_GetWindowsDirectory():
    GetWindowsDirectory()


@pytest.mark.skip
def test_GlobalMemoryStatus():
    GlobalMemoryStatus()


@pytest.mark.skip
def test_GlobalMemoryStatusEx():
    GlobalMemoryStatusEx()


@pytest.mark.skip
def test_HIBYTE():
    HIBYTE()


@pytest.mark.skip
def test_HIWORD():
    HIWORD()


@pytest.mark.skip
def test_InitiateSystemShutdown():
    InitiateSystemShutdown()


@pytest.mark.skip
def test_LOBYTE():
    LOBYTE()


@pytest.mark.skip
def test_LOWORD():
    LOWORD()


@pytest.mark.skip
def test_LoadCursor():
    LoadCursor()


@pytest.mark.skip
def test_LoadKeyboardLayout():
    LoadKeyboardLayout()


@pytest.mark.skip
def test_LoadLibrary():
    LoadLibrary()


@pytest.mark.skip
def test_LoadLibraryEx():
    LoadLibraryEx()


@pytest.mark.skip
def test_LoadResource():
    LoadResource()


@pytest.mark.skip
def test_LoadString():
    LoadString()


@pytest.mark.skip
def test_MAKELANGID():
    MAKELANGID()


@pytest.mark.skip
def test_MAKELONG():
    MAKELONG()


@pytest.mark.skip
def test_MAKEWORD():
    MAKEWORD()


@pytest.mark.skip
def test_MessageBeep():
    MessageBeep()


@pytest.mark.skip
def test_MessageBox():
    MessageBox()


@pytest.mark.skip
def test_MonitorFromPoint():
    MonitorFromPoint()


@pytest.mark.skip
def test_MonitorFromRect():
    MonitorFromRect()


@pytest.mark.skip
def test_MonitorFromWindow():
    MonitorFromWindow()


@pytest.mark.skip
def test_MoveFile():
    MoveFile()


@pytest.mark.skip
def test_MoveFileEx():
    MoveFileEx()


@pytest.mark.skip
def test_OpenProcess():
    OpenProcess()


@pytest.mark.skip
def test_OutputDebugString():
    OutputDebugString()


@pytest.mark.skip
def test_PostMessage():
    PostMessage()


@pytest.mark.skip
def test_PostQuitMessage():
    PostQuitMessage()


@pytest.mark.skip
def test_PostThreadMessage():
    PostThreadMessage()


@pytest.mark.skip
def test_RGB():
    RGB()


@pytest.mark.skip
def test_RegCloseKey():
    RegCloseKey()


@pytest.mark.skip
def test_RegConnectRegistry():
    RegConnectRegistry()


@pytest.mark.skip
def test_RegCopyTree():
    RegCopyTree()


@pytest.mark.skip
def test_RegCreateKey():
    RegCreateKey()


@pytest.mark.skip
def test_RegCreateKeyEx():
    RegCreateKeyEx()


@pytest.mark.skip
def test_RegDeleteKey():
    RegDeleteKey()


@pytest.mark.skip
def test_RegDeleteKeyEx():
    RegDeleteKeyEx()


@pytest.mark.skip
def test_RegDeleteTree():
    RegDeleteTree()


@pytest.mark.skip
def test_RegDeleteValue():
    RegDeleteValue()


@pytest.mark.skip
def test_RegEnumKey():
    RegEnumKey()


@pytest.mark.skip
def test_RegEnumKeyEx():
    RegEnumKeyEx()


@pytest.mark.skip
def test_RegEnumKeyExW():
    RegEnumKeyExW()


@pytest.mark.skip
def test_RegEnumValue():
    RegEnumValue()


@pytest.mark.skip
def test_RegFlushKey():
    RegFlushKey()


@pytest.mark.skip
def test_RegGetKeySecurity():
    RegGetKeySecurity()


@pytest.mark.skip
def test_RegLoadKey():
    RegLoadKey()


@pytest.mark.skip
def test_RegNotifyChangeKeyValue():
    RegNotifyChangeKeyValue()


@pytest.mark.skip
def test_RegOpenCurrentUser():
    RegOpenCurrentUser()


@pytest.mark.skip
def test_RegOpenKey():
    RegOpenKey()


@pytest.mark.skip
def test_RegOpenKeyEx():
    RegOpenKeyEx()


@pytest.mark.skip
def test_RegOpenKeyTransacted():
    RegOpenKeyTransacted()


@pytest.mark.skip
def test_RegOverridePredefKey():
    RegOverridePredefKey()


@pytest.mark.skip
def test_RegQueryInfoKey():
    RegQueryInfoKey()


@pytest.mark.skip
def test_RegQueryInfoKeyW():
    RegQueryInfoKeyW()


@pytest.mark.skip
def test_RegQueryValue():
    RegQueryValue()


@pytest.mark.skip
def test_RegQueryValueEx():
    RegQueryValueEx()


@pytest.mark.skip
def test_RegRestoreKey():
    RegRestoreKey()


@pytest.mark.skip
def test_RegSaveKey():
    RegSaveKey()


@pytest.mark.skip
def test_RegSaveKeyEx():
    RegSaveKeyEx()


@pytest.mark.skip
def test_RegSetKeySecurity():
    RegSetKeySecurity()


@pytest.mark.skip
def test_RegSetValue():
    RegSetValue()


@pytest.mark.skip
def test_RegSetValueEx():
    RegSetValueEx()


@pytest.mark.skip
def test_RegUnLoadKey():
    RegUnLoadKey()


@pytest.mark.skip
def test_RegisterWindowMessage():
    RegisterWindowMessage()


@pytest.mark.skip
def test_SearchPath():
    SearchPath()


@pytest.mark.skip
def test_SendMessage():
    SendMessage()


@pytest.mark.skip
def test_SetClassLong():
    SetClassLong()


@pytest.mark.skip
def test_SetClassWord():
    SetClassWord()


@pytest.mark.skip
def test_SetConsoleCtrlHandler():
    SetConsoleCtrlHandler()


@pytest.mark.skip
def test_SetConsoleTitle():
    SetConsoleTitle()


@pytest.mark.skip
def test_SetCursor():
    SetCursor()


@pytest.mark.skip
def test_SetCursorPos():
    SetCursorPos()


@pytest.mark.skip
def test_SetDllDirectory():
    SetDllDirectory()


@pytest.mark.skip
def test_SetEnvironmentVariable():
    SetEnvironmentVariable()


@pytest.mark.skip
def test_SetErrorMode():
    SetErrorMode()


@pytest.mark.skip
def test_SetFileAttributes():
    SetFileAttributes()


@pytest.mark.skip
def test_SetHandleInformation():
    SetHandleInformation()


@pytest.mark.skip
def test_SetLastError():
    SetLastError()


@pytest.mark.skip
def test_SetLocalTime():
    SetLocalTime()


@pytest.mark.skip
def test_SetStdHandle():
    SetStdHandle()


@pytest.mark.skip
def test_SetSysColors():
    SetSysColors()


@pytest.mark.skip
def test_SetSystemFileCacheSize():
    SetSystemFileCacheSize()


@pytest.mark.skip
def test_SetSystemPowerState():
    SetSystemPowerState()


@pytest.mark.skip
def test_SetSystemTime():
    SetSystemTime()


@pytest.mark.skip
def test_SetThreadLocale():
    SetThreadLocale()


@pytest.mark.skip
def test_SetTimeZoneInformation():
    SetTimeZoneInformation()


@pytest.mark.skip
def test_SetWindowLong():
    SetWindowLong()


@pytest.mark.skip
def test_SetWindowWord():
    SetWindowWord()


@pytest.mark.skip
def test_ShellExecute():
    ShellExecute()


@pytest.mark.skip
def test_ShowCursor():
    ShowCursor()


@pytest.mark.skip
def test_Sleep():
    Sleep()


@pytest.mark.skip
def test_TerminateProcess():
    TerminateProcess()


@pytest.mark.skip
def test_Unicode():
    Unicode()


@pytest.mark.skip
def test_UpdateResource():
    UpdateResource()


@pytest.mark.skip
def test_VkKeyScan():
    VkKeyScan()


@pytest.mark.skip
def test_VkKeyScan():
    VkKeyScan()


@pytest.mark.skip
def test_WinExec():
    WinExec()


@pytest.mark.skip
def test_WinHelp():
    WinHelp()


@pytest.mark.skip
def test_WriteProfileSection():
    WriteProfileSection()


@pytest.mark.skip
def test_WriteProfileVal():
    WriteProfileVal()


@pytest.mark.skip
def test_keybd_event():
    keybd_event()


@pytest.mark.skip
def test_mouse_event():
    mouse_event()
