import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32security import *
def test_ACL():
    ACL()     



@pytest.mark.xfail
def test_AcceptSecurityContext():
    AcceptSecurityContext()     



@pytest.mark.xfail
def test_AcquireCredentialsHandle():
    AcquireCredentialsHandle()     



@pytest.mark.xfail
def test_AdjustTokenGroups():
    AdjustTokenGroups()     



@pytest.mark.xfail
def test_AdjustTokenPrivileges():
    AdjustTokenPrivileges()     



def test_AllocateLocallyUniqueId():
    AllocateLocallyUniqueId()     



@pytest.mark.xfail
def test_CheckTokenMembership():
    CheckTokenMembership()     



@pytest.mark.xfail
def test_ConvertSecurityDescriptorToStringSecurityDescriptor():
    ConvertSecurityDescriptorToStringSecurityDescriptor()     



@pytest.mark.xfail
def test_ConvertSidToStringSid():
    ConvertSidToStringSid()     



@pytest.mark.xfail
def test_ConvertStringSecurityDescriptorToSecurityDescriptor():
    ConvertStringSecurityDescriptorToSecurityDescriptor()     



@pytest.mark.xfail
def test_ConvertStringSidToSid():
    ConvertStringSidToSid()     



@pytest.mark.xfail
def test_CreateRestrictedToken():
    CreateRestrictedToken()     



@pytest.mark.xfail
def test_CreateWellKnownSid():
    CreateWellKnownSid()     



def test_CryptEnumProviders():
    CryptEnumProviders()     



@pytest.mark.xfail
def test_DsBind():
    DsBind()     



@pytest.mark.xfail
def test_DsCrackNames():
    DsCrackNames()     



@pytest.mark.xfail
def test_DsGetDcName():
    DsGetDcName()     



@pytest.mark.xfail
def test_DsGetSpn():
    DsGetSpn()     



@pytest.mark.xfail
def test_DsListDomainsInSite():
    DsListDomainsInSite()     



@pytest.mark.xfail
def test_DsListInfoForServer():
    DsListInfoForServer()     



@pytest.mark.xfail
def test_DsListRoles():
    DsListRoles()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsListServersInSite():
    DsListServersInSite()     



@pytest.mark.xfail
def test_DsUnBind():
    DsUnBind()     



@pytest.mark.xfail
def test_DsWriteAccountSpn():
    DsWriteAccountSpn()     



@pytest.mark.xfail
def test_DuplicateToken():
    DuplicateToken()     



@pytest.mark.xfail
def test_DuplicateTokenEx():
    DuplicateTokenEx()     



def test_EnumerateSecurityPackages():
    EnumerateSecurityPackages()     



@pytest.mark.xfail
def test_GetBinarySid():
    GetBinarySid()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_GetFileSecurity():
    GetFileSecurity()     



@pytest.mark.xfail
def test_GetKernelObjectSecurity():
    GetKernelObjectSecurity()     



@pytest.mark.xfail
def test_GetNamedSecurityInfo():
    GetNamedSecurityInfo()     



@pytest.mark.xfail
def test_GetSecurityInfo():
    GetSecurityInfo()     



@pytest.mark.xfail
def test_GetTokenInformation():
    GetTokenInformation()     



@pytest.mark.xfail
def test_GetUserObjectSecurity():
    GetUserObjectSecurity()     



@pytest.mark.xfail
def test_ImpersonateAnonymousToken():
    ImpersonateAnonymousToken()     



@pytest.mark.xfail
def test_ImpersonateLoggedOnUser():
    ImpersonateLoggedOnUser()     



@pytest.mark.xfail
def test_ImpersonateNamedPipeClient():
    ImpersonateNamedPipeClient()     



@pytest.mark.xfail
def test_ImpersonateSelf():
    ImpersonateSelf()     



@pytest.mark.xfail
def test_InitializeSecurityContext():
    InitializeSecurityContext()     



@pytest.mark.xfail
def test_IsTokenRestricted():
    IsTokenRestricted()     



@pytest.mark.xfail
def test_LogonUser():
    LogonUser()     



@pytest.mark.xfail
def test_LogonUserEx():
    LogonUserEx()     



@pytest.mark.xfail
def test_LookupAccountName():
    LookupAccountName()     



@pytest.mark.xfail
def test_LookupAccountSid():
    LookupAccountSid()     



@pytest.mark.xfail
def test_LookupPrivilegeDisplayName():
    LookupPrivilegeDisplayName()     



@pytest.mark.xfail
def test_LookupPrivilegeName():
    LookupPrivilegeName()     



@pytest.mark.xfail
def test_LookupPrivilegeValue():
    LookupPrivilegeValue()     



@pytest.mark.xfail
def test_LsaAddAccountRights():
    LsaAddAccountRights()     



@pytest.mark.xfail
def test_LsaCallAuthenticationPackage():
    LsaCallAuthenticationPackage()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaClose():
    LsaClose()     



def test_LsaConnectUntrusted():
    LsaConnectUntrusted()     



@pytest.mark.xfail
def test_LsaDeregisterLogonProcess():
    LsaDeregisterLogonProcess()     



@pytest.mark.xfail
def test_LsaEnumerateAccountRights():
    LsaEnumerateAccountRights()     



@pytest.mark.xfail
def test_LsaEnumerateAccountsWithUserRight():
    LsaEnumerateAccountsWithUserRight()     



def test_LsaEnumerateLogonSessions():
    LsaEnumerateLogonSessions()     



@pytest.mark.xfail
def test_LsaGetLogonSessionData():
    LsaGetLogonSessionData()     



@pytest.mark.xfail
def test_LsaLookupAuthenticationPackage():
    LsaLookupAuthenticationPackage()     



@pytest.mark.xfail
def test_LsaOpenPolicy():
    LsaOpenPolicy()     



@pytest.mark.xfail
def test_LsaQueryInformationPolicy():
    LsaQueryInformationPolicy()     



@pytest.mark.xfail
def test_LsaRegisterLogonProcess():
    LsaRegisterLogonProcess()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaRegisterPolicyChangeNotification():
    LsaRegisterPolicyChangeNotification()     



@pytest.mark.xfail
def test_LsaRemoveAccountRights():
    LsaRemoveAccountRights()     



@pytest.mark.xfail
def test_LsaRetrievePrivateData():
    LsaRetrievePrivateData()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_LsaSetInformationPolicy():
    LsaSetInformationPolicy()     



@pytest.mark.xfail
def test_LsaStorePrivateData():
    LsaStorePrivateData()     



@pytest.mark.xfail
def test_LsaUnregisterPolicyChangeNotification():
    LsaUnregisterPolicyChangeNotification()     



@pytest.mark.xfail
def test_MapGenericMask():
    MapGenericMask()     



@pytest.mark.xfail
def test_OpenProcessToken():
    OpenProcessToken()     



@pytest.mark.xfail
def test_OpenThreadToken():
    OpenThreadToken()     



@pytest.mark.xfail
def test_QuerySecurityPackageInfo():
    QuerySecurityPackageInfo()     



def test_RevertToSelf():
    RevertToSelf()     



def test_SECURITY_ATTRIBUTES():
    SECURITY_ATTRIBUTES()     



def test_SECURITY_DESCRIPTOR():
    SECURITY_DESCRIPTOR()     



def test_SID():
    SID()     



@pytest.mark.xfail
def test_SetFileSecurity():
    SetFileSecurity()     



@pytest.mark.xfail
def test_SetKernelObjectSecurity():
    SetKernelObjectSecurity()     



@pytest.mark.xfail
def test_SetNamedSecurityInfo():
    SetNamedSecurityInfo()     



@pytest.mark.xfail
def test_SetSecurityInfo():
    SetSecurityInfo()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_SetThreadToken():
    SetThreadToken()     



@pytest.mark.xfail
def test_SetTokenInformation():
    SetTokenInformation()     



@pytest.mark.xfail
def test_SetUserObjectSecurity():
    SetUserObjectSecurity()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_TranslateName():
    TranslateName()     


