import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32pipe import *
@pytest.mark.xfail
def test_CallNamedPipe():
    CallNamedPipe()     



@pytest.mark.xfail
def test_ConnectNamedPipe():
    ConnectNamedPipe()     



@pytest.mark.xfail
def test_CreateNamedPipe():
    CreateNamedPipe()     



@pytest.mark.xfail
def test_CreatePipe():
    CreatePipe()     



@pytest.mark.xfail
def test_DisconnectNamedPipe():
    DisconnectNamedPipe()     



@pytest.mark.xfail
def test_FdCreatePipe():
    FdCreatePipe()     



@pytest.mark.xfail
def test_GetNamedPipeClientProcessId():
    GetNamedPipeClientProcessId()     



@pytest.mark.xfail
def test_GetNamedPipeClientSessionId():
    GetNamedPipeClientSessionId()     



@pytest.mark.xfail
def test_GetNamedPipeHandleState():
    GetNamedPipeHandleState()     



@pytest.mark.xfail
def test_GetNamedPipeInfo():
    GetNamedPipeInfo()     



@pytest.mark.xfail
def test_GetNamedPipeServerProcessId():
    GetNamedPipeServerProcessId()     



@pytest.mark.xfail
def test_GetNamedPipeServerSessionId():
    GetNamedPipeServerSessionId()     



@pytest.mark.xfail
def test_GetOverlappedResult():
    GetOverlappedResult()     



@pytest.mark.xfail
def test_PeekNamedPipe():
    PeekNamedPipe()     



@pytest.mark.xfail
def test_SetNamedPipeHandleState():
    SetNamedPipeHandleState()     



@pytest.mark.xfail
def test_TransactNamedPipe():
    TransactNamedPipe()     



@pytest.mark.xfail
def test_WaitNamedPipe():
    WaitNamedPipe()     



@pytest.mark.xfail
def test_popen():
    popen()     



@pytest.mark.xfail
def test_popen2():
    popen2()     



@pytest.mark.xfail
def test_popen3():
    popen3()     



@pytest.mark.xfail
def test_popen4():
    popen4()     


