import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32inet import *
@pytest.mark.xfail
def test_CommitUrlCacheEntry():
    CommitUrlCacheEntry()     



@pytest.mark.xfail
def test_CreateUrlCacheEntry():
    CreateUrlCacheEntry()     



def test_CreateUrlCacheGroup():
    CreateUrlCacheGroup()     



@pytest.mark.xfail
def test_DeleteUrlCacheEntry():
    DeleteUrlCacheEntry()     



@pytest.mark.xfail
def test_DeleteUrlCacheGroup():
    DeleteUrlCacheGroup()     



@pytest.mark.xfail
def test_FindCloseUrlCache():
    FindCloseUrlCache()     



@pytest.mark.xfail
def test_FindFirstUrlCacheEntry():
    FindFirstUrlCacheEntry()     



@pytest.mark.xfail
def test_FindFirstUrlCacheEntryEx():
    FindFirstUrlCacheEntryEx()     



def test_FindFirstUrlCacheGroup():
    FindFirstUrlCacheGroup()     



@pytest.mark.xfail
def test_FindNextUrlCacheEntry():
    FindNextUrlCacheEntry()     



@pytest.mark.xfail
def test_FindNextUrlCacheEntryEx():
    FindNextUrlCacheEntryEx()     



@pytest.mark.xfail
def test_FindNextUrlCacheGroup():
    FindNextUrlCacheGroup()     



@pytest.mark.xfail
def test_FtpCommand():
    FtpCommand()     



@pytest.mark.xfail
def test_FtpOpenFile():
    FtpOpenFile()     



@pytest.mark.xfail
def test_GetUrlCacheEntryInfo():
    GetUrlCacheEntryInfo()     



@pytest.mark.xfail
def test_GetUrlCacheGroupAttribute():
    GetUrlCacheGroupAttribute()     



def test_InternetAttemptConnect():
    InternetAttemptConnect()     



@pytest.mark.xfail
def test_InternetCanonicalizeUrl():
    InternetCanonicalizeUrl()     



@pytest.mark.xfail
def test_InternetCheckConnection():
    InternetCheckConnection()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_InternetCloseHandle():
    InternetCloseHandle()     



@pytest.mark.xfail
def test_InternetConnect():
    InternetConnect()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_InternetGetCookie():
    InternetGetCookie()     



@pytest.mark.xfail
def test_InternetGetLastResponseInfo():
    InternetGetLastResponseInfo()     



@pytest.mark.xfail
def test_InternetGoOnline():
    InternetGoOnline()     



@pytest.mark.xfail
def test_InternetOpen():
    InternetOpen()     



@pytest.mark.xfail
def test_InternetOpenUrl():
    InternetOpenUrl()     



@pytest.mark.xfail
def test_InternetQueryOption():
    InternetQueryOption()     



@pytest.mark.xfail
def test_InternetReadFile():
    InternetReadFile()     



@pytest.mark.xfail
def test_InternetSetCookie():
    InternetSetCookie()     



@pytest.mark.xfail
def test_InternetSetOption():
    InternetSetOption()     



@pytest.mark.xfail
def test_InternetWriteFile():
    InternetWriteFile()     



@pytest.mark.xfail
def test_SetUrlCacheEntryGroup():
    SetUrlCacheEntryGroup()     



@pytest.mark.xfail
def test_SetUrlCacheGroupAttribute():
    SetUrlCacheGroupAttribute()     


