import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32pdh import *
@pytest.mark.xfail
def test_AddCounter():
    AddCounter()     



@pytest.mark.xfail
def test_BrowseCounters():
    BrowseCounters()     



@pytest.mark.xfail
def test_CloseQuery():
    CloseQuery()     



@pytest.mark.xfail
def test_CollectQueryData():
    CollectQueryData()     



@pytest.mark.xfail
def test_ConnectMachine():
    ConnectMachine()     



@pytest.mark.xfail
def test_EnumObjectItems():
    EnumObjectItems()     



@pytest.mark.xfail
def test_EnumObjects():
    EnumObjects()     



@pytest.mark.xfail
def test_ExpandCounterPath():
    ExpandCounterPath()     



@pytest.mark.xfail
def test_GetCounterInfo():
    GetCounterInfo()     



@pytest.mark.xfail
def test_GetFormattedCounterValue():
    GetFormattedCounterValue()     



@pytest.mark.xfail
def test_LookupPerfIndexByName():
    LookupPerfIndexByName()     



@pytest.mark.xfail
def test_LookupPerfNameByIndex():
    LookupPerfNameByIndex()     



@pytest.mark.xfail
def test_MakeCounterPath():
    MakeCounterPath()     



def test_OpenQuery():
    OpenQuery()     



@pytest.mark.xfail
def test_ParseCounterPath():
    ParseCounterPath()     



@pytest.mark.xfail
def test_ParseInstanceName():
    ParseInstanceName()     



@pytest.mark.xfail
def test_RemoveCounter():
    RemoveCounter()     



@pytest.mark.xfail
def test_SetCounterScaleFactor():
    SetCounterScaleFactor()     



@pytest.mark.xfail
def test_ValidatePath():
    ValidatePath()     


