import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32file import *
@pytest.mark.xfail
def test_AcceptEx():
    AcceptEx()     



@pytest.mark.xfail
def test_AddUsersToEncryptedFile():
    AddUsersToEncryptedFile()     



@pytest.mark.xfail
def test_AllocateReadBuffer():
    AllocateReadBuffer()     



def test_AreFileApisANSI():
    AreFileApisANSI()     



@pytest.mark.xfail
def test_BackupRead():
    BackupRead()     



@pytest.mark.xfail
def test_BackupSeek():
    BackupSeek()     



@pytest.mark.xfail
def test_BackupWrite():
    BackupWrite()     



@pytest.mark.xfail
def test_BuildCommDCB():
    BuildCommDCB()     



@pytest.mark.xfail
def test_CalculateSocketEndPointSize():
    CalculateSocketEndPointSize()     



@pytest.mark.xfail
def test_CancelIo():
    CancelIo()     



@pytest.mark.xfail
def test_ClearCommBreak():
    ClearCommBreak()     



@pytest.mark.xfail
def test_ClearCommError():
    ClearCommError()     



@pytest.mark.xfail
def test_CloseEncryptedFileRaw():
    CloseEncryptedFileRaw()     



@pytest.mark.xfail
def test_CloseHandle():
    CloseHandle()     



@pytest.mark.xfail
def test_ConnectEx():
    ConnectEx()     



@pytest.mark.xfail
def test_CopyFile():
    CopyFile()     



@pytest.mark.xfail
def test_CopyFileEx():
    CopyFileEx()     



@pytest.mark.xfail
def test_CopyFileW():
    CopyFileW()     



@pytest.mark.xfail
def test_CreateDirectory():
    CreateDirectory()     



@pytest.mark.xfail
def test_CreateDirectoryEx():
    CreateDirectoryEx()     



@pytest.mark.xfail
def test_CreateDirectoryExW():
    CreateDirectoryExW()     



@pytest.mark.xfail
def test_CreateDirectoryW():
    CreateDirectoryW()     



@pytest.mark.xfail
def test_CreateFile():
    CreateFile()     



@pytest.mark.xfail
def test_CreateFileW():
    CreateFileW()     



@pytest.mark.xfail
def test_CreateHardLink():
    CreateHardLink()     



@pytest.mark.xfail
def test_CreateIoCompletionPort():
    CreateIoCompletionPort()     



@pytest.mark.xfail
def test_CreateMailslot():
    CreateMailslot()     



@pytest.mark.xfail
def test_CreateSymbolicLink():
    CreateSymbolicLink()     



@pytest.mark.xfail
def test_DecryptFile():
    DecryptFile()     



@pytest.mark.xfail
def test_DefineDosDevice():
    DefineDosDevice()     



@pytest.mark.xfail
def test_DefineDosDeviceW():
    DefineDosDeviceW()     



@pytest.mark.xfail
def test_DeleteFile():
    DeleteFile()     



@pytest.mark.xfail
def test_DeleteFileW():
    DeleteFileW()     



@pytest.mark.xfail
def test_DeleteVolumeMountPoint():
    DeleteVolumeMountPoint()     



@pytest.mark.xfail
def test_DeviceIoControl():
    DeviceIoControl()     



@pytest.mark.xfail
def test_DuplicateEncryptionInfoFile():
    DuplicateEncryptionInfoFile()     



@pytest.mark.xfail
def test_EncryptFile():
    EncryptFile()     



@pytest.mark.xfail
def test_EncryptionDisable():
    EncryptionDisable()     



@pytest.mark.xfail
def test_EscapeCommFunction():
    EscapeCommFunction()     



@pytest.mark.xfail
def test_FILE_NOTIFY_INFORMATION():
    FILE_NOTIFY_INFORMATION()     



@pytest.mark.xfail
def test_FileEncryptionStatus():
    FileEncryptionStatus()     



@pytest.mark.xfail
def test_FindClose():
    FindClose()     



@pytest.mark.xfail
def test_FindCloseChangeNotification():
    FindCloseChangeNotification()     



@pytest.mark.xfail
def test_FindFileNames():
    FindFileNames()     



@pytest.mark.xfail
def test_FindFilesIterator():
    FindFilesIterator()     



@pytest.mark.xfail
def test_FindFilesW():
    FindFilesW()     



@pytest.mark.xfail
def test_FindFirstChangeNotification():
    FindFirstChangeNotification()     



@pytest.mark.xfail
def test_FindNextChangeNotification():
    FindNextChangeNotification()     



@pytest.mark.xfail
def test_FindStreams():
    FindStreams()     



@pytest.mark.xfail
def test_FlushFileBuffers():
    FlushFileBuffers()     



@pytest.mark.xfail
def test_GetAcceptExSockaddrs():
    GetAcceptExSockaddrs()     



@pytest.mark.xfail
def test_GetBinaryType():
    GetBinaryType()     



@pytest.mark.xfail
def test_GetCommMask():
    GetCommMask()     



@pytest.mark.xfail
def test_GetCommModemStatus():
    GetCommModemStatus()     



@pytest.mark.xfail
def test_GetCommState():
    GetCommState()     



@pytest.mark.xfail
def test_GetCommTimeouts():
    GetCommTimeouts()     



@pytest.mark.xfail
def test_GetCompressedFileSize():
    GetCompressedFileSize()     



@pytest.mark.xfail
def test_GetDiskFreeSpace():
    GetDiskFreeSpace()     



@pytest.mark.xfail
def test_GetDiskFreeSpaceEx():
    GetDiskFreeSpaceEx()     



@pytest.mark.xfail
def test_GetDriveType():
    GetDriveType()     



@pytest.mark.xfail
def test_GetDriveTypeW():
    GetDriveTypeW()     



@pytest.mark.xfail
def test_GetFileAttributes():
    GetFileAttributes()     



@pytest.mark.xfail
def test_GetFileAttributesEx():
    GetFileAttributesEx()     



@pytest.mark.xfail
def test_GetFileAttributesW():
    GetFileAttributesW()     



@pytest.mark.xfail
def test_GetFileInformationByHandle():
    GetFileInformationByHandle()     



@pytest.mark.xfail
def test_GetFileSize():
    GetFileSize()     



@pytest.mark.xfail
def test_GetFileTime():
    GetFileTime()     



@pytest.mark.xfail
def test_GetFileType():
    GetFileType()     



@pytest.mark.xfail
def test_GetFinalPathNameByHandle():
    GetFinalPathNameByHandle()     



@pytest.mark.xfail
def test_GetFullPathName():
    GetFullPathName()     



def test_GetLogicalDrives():
    GetLogicalDrives()     



@pytest.mark.xfail
def test_GetLongPathName():
    GetLongPathName()     



@pytest.mark.xfail
def test_GetMailslotInfo():
    GetMailslotInfo()     



@pytest.mark.xfail
def test_GetOverlappedResult():
    GetOverlappedResult()     



@pytest.mark.xfail
def test_GetQueuedCompletionStatus():
    GetQueuedCompletionStatus()     



@pytest.mark.xfail
def test_GetVolumeNameForVolumeMountPoint():
    GetVolumeNameForVolumeMountPoint()     



@pytest.mark.xfail
def test_GetVolumePathName():
    GetVolumePathName()     



@pytest.mark.xfail
def test_GetVolumePathNamesForVolumeName():
    GetVolumePathNamesForVolumeName()     



@pytest.mark.xfail
def test_LockFile():
    LockFile()     



@pytest.mark.xfail
def test_LockFileEx():
    LockFileEx()     



@pytest.mark.xfail
def test_MoveFile():
    MoveFile()     



@pytest.mark.xfail
def test_MoveFileEx():
    MoveFileEx()     



@pytest.mark.xfail
def test_MoveFileExW():
    MoveFileExW()     



@pytest.mark.xfail
def test_MoveFileW():
    MoveFileW()     



@pytest.mark.xfail
def test_MoveFileWithProgress():
    MoveFileWithProgress()     



@pytest.mark.xfail
def test_OpenEncryptedFileRaw():
    OpenEncryptedFileRaw()     



@pytest.mark.xfail
def test_PostQueuedCompletionStatus():
    PostQueuedCompletionStatus()     



@pytest.mark.xfail
def test_PurgeComm():
    PurgeComm()     



@pytest.mark.xfail
def test_QueryDosDevice():
    QueryDosDevice()     



@pytest.mark.xfail
def test_QueryRecoveryAgentsOnEncryptedFile():
    QueryRecoveryAgentsOnEncryptedFile()     



@pytest.mark.xfail
def test_QueryUsersOnEncryptedFile():
    QueryUsersOnEncryptedFile()     



@pytest.mark.xfail
def test_ReadDirectoryChangesW():
    ReadDirectoryChangesW()     



@pytest.mark.xfail
def test_ReadEncryptedFileRaw():
    ReadEncryptedFileRaw()     



@pytest.mark.xfail
def test_ReadFile():
    ReadFile()     



@pytest.mark.xfail
def test_RemoveDirectory():
    RemoveDirectory()     



@pytest.mark.xfail
def test_RemoveUsersFromEncryptedFile():
    RemoveUsersFromEncryptedFile()     



@pytest.mark.xfail
def test_ReplaceFile():
    ReplaceFile()     



@pytest.mark.xfail
def test_SetCommBreak():
    SetCommBreak()     



@pytest.mark.xfail
def test_SetCommMask():
    SetCommMask()     



@pytest.mark.xfail
def test_SetCommState():
    SetCommState()     



@pytest.mark.xfail
def test_SetCommTimeouts():
    SetCommTimeouts()     



@pytest.mark.xfail
def test_SetCurrentDirectory():
    SetCurrentDirectory()     



@pytest.mark.xfail
def test_SetEndOfFile():
    SetEndOfFile()     



def test_SetFileApisToANSI():
    SetFileApisToANSI()     



def test_SetFileApisToOEM():
    SetFileApisToOEM()     



@pytest.mark.xfail
def test_SetFileAttributes():
    SetFileAttributes()     



@pytest.mark.xfail
def test_SetFileAttributesW():
    SetFileAttributesW()     



@pytest.mark.xfail
def test_SetFilePointer():
    SetFilePointer()     



@pytest.mark.xfail
def test_SetFileShortName():
    SetFileShortName()     



@pytest.mark.xfail
def test_SetFileTime():
    SetFileTime()     



@pytest.mark.xfail
def test_SetMailslotInfo():
    SetMailslotInfo()     



@pytest.mark.xfail
def test_SetVolumeLabel():
    SetVolumeLabel()     



@pytest.mark.xfail
def test_SetVolumeMountPoint():
    SetVolumeMountPoint()     



@pytest.mark.xfail
def test_SetupComm():
    SetupComm()     



def test_SfcGetNextProtectedFile():
    SfcGetNextProtectedFile()     



@pytest.mark.xfail
def test_SfcIsFileProtected():
    SfcIsFileProtected()     



@pytest.mark.xfail
def test_TransmitCommChar():
    TransmitCommChar()     



@pytest.mark.xfail
def test_TransmitFile():
    TransmitFile()     



@pytest.mark.xfail
def test_UnlockFile():
    UnlockFile()     



@pytest.mark.xfail
def test_UnlockFileEx():
    UnlockFileEx()     



@pytest.mark.xfail
def test_WSAAsyncSelect():
    WSAAsyncSelect()     



@pytest.mark.xfail
def test_WSAEventSelect():
    WSAEventSelect()     



@pytest.mark.xfail
def test_WSARecv():
    WSARecv()     



@pytest.mark.xfail
def test_WSASend():
    WSASend()     



@pytest.mark.xfail
def test_WaitCommEvent():
    WaitCommEvent()     



@pytest.mark.xfail
def test_WriteEncryptedFileRaw():
    WriteEncryptedFileRaw()     



@pytest.mark.xfail
def test_WriteFile():
    WriteFile()     



@pytest.mark.xfail
def test_get_osfhandle():
    get_osfhandle()     



@pytest.mark.xfail
def test_getmaxstdio():
    getmaxstdio()     



@pytest.mark.xfail
def test_open_osfhandle():
    open_osfhandle()     



@pytest.mark.xfail
def test_setmaxstdio():
    setmaxstdio()     


