from exchdapi import *
def test_HrAdminProgramExists():
    HrAdminProgramExists()     



def test_HrCreateGatewayProfile():
    HrCreateGatewayProfile()     



def test_HrCreateMailboxAgentProfile():
    HrCreateMailboxAgentProfile()     



def test_HrEnumContainers():
    HrEnumContainers()     



def test_HrEnumOrganizations():
    HrEnumOrganizations()     



def test_HrEnumSiteAdmins():
    HrEnumSiteAdmins()     



def test_HrEnumSites():
    HrEnumSites()     



def test_HrGetServiceAccountName():
    HrGetServiceAccountName()     



def test_HrInstallMailboxAgent():
    HrInstallMailboxAgent()     



def test_HrInstallService():
    HrInstallService()     



def test_HrMailboxAgentExists():
    HrMailboxAgentExists()     



def test_HrRemoveMailboxAgent():
    HrRemoveMailboxAgent()     



def test_HrRemoveProfile():
    HrRemoveProfile()     


