import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32console import *
@pytest.mark.xfail
def test_AddConsoleAlias():
    AddConsoleAlias()     



@pytest.mark.xfail
def test_AllocConsole():
    AllocConsole()     



@pytest.mark.xfail
def test_AttachConsole():
    AttachConsole()     



def test_CreateConsoleScreenBuffer():
    CreateConsoleScreenBuffer()     



def test_FreeConsole():
    FreeConsole()     



@pytest.mark.xfail
def test_GenerateConsoleCtrlEvent():
    GenerateConsoleCtrlEvent()     



def test_GetConsoleAliasExes():
    GetConsoleAliasExes()     



@pytest.mark.xfail
def test_GetConsoleAliases():
    GetConsoleAliases()     



def test_GetConsoleCP():
    GetConsoleCP()     



@pytest.mark.xfail
def test_GetConsoleDisplayMode():
    GetConsoleDisplayMode()     



def test_GetConsoleOutputCP():
    GetConsoleOutputCP()     



@pytest.mark.xfail
def test_GetConsoleProcessList():
    GetConsoleProcessList()     



@pytest.mark.xfail
@pytest.mark.xfail
def test_GetConsoleSelectionInfo():
    GetConsoleSelectionInfo()     



@pytest.mark.xfail
def test_GetConsoleTitle():
    GetConsoleTitle()     



def test_GetConsoleWindow():
    GetConsoleWindow()     



def test_GetNumberOfConsoleFonts():
    GetNumberOfConsoleFonts()     



@pytest.mark.xfail
def test_GetStdHandle():
    GetStdHandle()     



@pytest.mark.xfail
def test_SetConsoleCP():
    SetConsoleCP()     



@pytest.mark.xfail
def test_SetConsoleOutputCP():
    SetConsoleOutputCP()     



@pytest.mark.xfail
def test_SetConsoleTitle():
    SetConsoleTitle()     


