import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32service import *
@pytest.mark.xfail
def test_ChangeServiceConfig():
    ChangeServiceConfig()     



@pytest.mark.xfail
def test_ChangeServiceConfig2():
    ChangeServiceConfig2()     



@pytest.mark.xfail
def test_CloseServiceHandle():
    CloseServiceHandle()     



@pytest.mark.xfail
def test_ControlService():
    ControlService()     



@pytest.mark.xfail
def test_CreateDesktop():
    CreateDesktop()     



@pytest.mark.xfail
def test_CreateService():
    CreateService()     



@pytest.mark.xfail
def test_CreateWindowStation():
    CreateWindowStation()     



@pytest.mark.xfail
def test_DeleteService():
    DeleteService()     



@pytest.mark.xfail
def test_EnumDependentServices():
    EnumDependentServices()     



@pytest.mark.xfail
def test_EnumServicesStatus():
    EnumServicesStatus()     



def test_EnumWindowStations():
    EnumWindowStations()     



def test_GetProcessWindowStation():
    GetProcessWindowStation()     



@pytest.mark.xfail
def test_GetServiceDisplayName():
    GetServiceDisplayName()     



@pytest.mark.xfail
def test_GetServiceKeyName():
    GetServiceKeyName()     



@pytest.mark.xfail
def test_GetThreadDesktop():
    GetThreadDesktop()     



@pytest.mark.xfail
def test_GetUserObjectInformation():
    GetUserObjectInformation()     



@pytest.mark.xfail
def test_LockServiceDatabase():
    LockServiceDatabase()     



@pytest.mark.xfail
def test_OpenDesktop():
    OpenDesktop()     



@pytest.mark.xfail
def test_OpenInputDesktop():
    OpenInputDesktop()     



@pytest.mark.xfail
def test_OpenSCManager():
    OpenSCManager()     



@pytest.mark.xfail
def test_OpenService():
    OpenService()     



@pytest.mark.xfail
def test_OpenWindowStation():
    OpenWindowStation()     



@pytest.mark.xfail
def test_QueryServiceConfig():
    QueryServiceConfig()     



@pytest.mark.xfail
def test_QueryServiceConfig2():
    QueryServiceConfig2()     



@pytest.mark.xfail
def test_QueryServiceLockStatus():
    QueryServiceLockStatus()     



@pytest.mark.xfail
def test_QueryServiceObjectSecurity():
    QueryServiceObjectSecurity()     



@pytest.mark.xfail
def test_QueryServiceStatus():
    QueryServiceStatus()     



@pytest.mark.xfail
def test_QueryServiceStatusEx():
    QueryServiceStatusEx()     



@pytest.mark.xfail
def test_SetServiceObjectSecurity():
    SetServiceObjectSecurity()     



@pytest.mark.xfail
def test_SetServiceStatus():
    SetServiceStatus()     



@pytest.mark.xfail
def test_SetUserObjectInformation():
    SetUserObjectInformation()     



@pytest.mark.xfail
def test_StartService():
    StartService()     



@pytest.mark.xfail
def test_UnlockServiceDatabase():
    UnlockServiceDatabase()     


