import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32wnet import *
def test_NCB():
    NCB()     



@pytest.mark.xfail
def test_NCBBuffer():
    NCBBuffer()     



def test_NETRESOURCE():
    NETRESOURCE()     



@pytest.mark.xfail
def test_Netbios():
    Netbios()     



@pytest.mark.xfail
def test_WNetAddConnection2():
    WNetAddConnection2()     



@pytest.mark.xfail
def test_WNetAddConnection3():
    WNetAddConnection3()     



@pytest.mark.xfail
def test_WNetCancelConnection2():
    WNetCancelConnection2()     



@pytest.mark.xfail
def test_WNetCloseEnum():
    WNetCloseEnum()     



@pytest.mark.xfail
def test_WNetEnumResource():
    WNetEnumResource()     



def test_WNetGetLastError():
    WNetGetLastError()     



@pytest.mark.xfail
def test_WNetGetResourceInformation():
    WNetGetResourceInformation()     



@pytest.mark.xfail
def test_WNetGetResourceParent():
    WNetGetResourceParent()     



@pytest.mark.xfail
def test_WNetGetUniversalName():
    WNetGetUniversalName()     



def test_WNetGetUser():
    WNetGetUser()     



@pytest.mark.xfail
def test_WNetOpenEnum():
    WNetOpenEnum()     


