import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32clipboard import *
@pytest.mark.xfail
def test_ChangeClipboardChain():
    ChangeClipboardChain()     



@pytest.mark.xfail
def test_CloseClipboard():
    CloseClipboard()     



@pytest.mark.xfail
def test_CountClipboardFormats():
    CountClipboardFormats()     



@pytest.mark.xfail
def test_EmptyClipboard():
    EmptyClipboard()     



@pytest.mark.xfail
def test_EnumClipboardFormats():
    EnumClipboardFormats()     



@pytest.mark.xfail
def test_GetClipboardData():
    GetClipboardData()     



@pytest.mark.xfail
def test_GetClipboardDataHandle():
    GetClipboardDataHandle()     



@pytest.mark.xfail
def test_GetClipboardFormatName():
    GetClipboardFormatName()     



@pytest.mark.xfail
def test_GetClipboardOwner():
    GetClipboardOwner()     



def test_GetClipboardSequenceNumber():
    GetClipboardSequenceNumber()     



@pytest.mark.xfail
def test_GetClipboardViewer():
    GetClipboardViewer()     



@pytest.mark.xfail
def test_GetGlobalMemory():
    GetGlobalMemory()     



@pytest.mark.xfail
def test_GetOpenClipboardWindow():
    GetOpenClipboardWindow()     



@pytest.mark.xfail
def test_GetPriorityClipboardFormat():
    GetPriorityClipboardFormat()     



@pytest.mark.xfail
def test_IsClipboardFormatAvailable():
    IsClipboardFormatAvailable()     



def test_OpenClipboard():
    OpenClipboard()     



@pytest.mark.xfail
def test_RegisterClipboardFormat():
    RegisterClipboardFormat()     



@pytest.mark.xfail
def test_SetClipboardData():
    SetClipboardData()     



@pytest.mark.xfail
def test_SetClipboardText():
    SetClipboardText()     



@pytest.mark.xfail
def test_SetClipboardViewer():
    SetClipboardViewer()     


