import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
import pytest
from win32print import *
@pytest.mark.xfail
def test_AbortDoc():
    AbortDoc()     



@pytest.mark.xfail
def test_AbortPrinter():
    AbortPrinter()     



@pytest.mark.xfail
def test_AddForm():
    AddForm()     



@pytest.mark.xfail
def test_AddJob():
    AddJob()     



@pytest.mark.xfail
def test_AddPrinter():
    AddPrinter()     



@pytest.mark.xfail
def test_AddPrinterConnection():
    AddPrinterConnection()     



@pytest.mark.xfail
def test_ClosePrinter():
    ClosePrinter()     



@pytest.mark.xfail
def test_DeleteForm():
    DeleteForm()     



@pytest.mark.xfail
def test_DeletePrinter():
    DeletePrinter()     



@pytest.mark.xfail
def test_DeletePrinterConnection():
    DeletePrinterConnection()     



@pytest.mark.xfail
def test_DeletePrinterDriver():
    DeletePrinterDriver()     



@pytest.mark.xfail
def test_DeletePrinterDriverEx():
    DeletePrinterDriverEx()     



@pytest.mark.xfail
def test_DeviceCapabilities():
    DeviceCapabilities()     



@pytest.mark.xfail
def test_DocumentProperties():
    DocumentProperties()     



@pytest.mark.xfail
def test_EndDoc():
    EndDoc()     



@pytest.mark.xfail
def test_EndDocPrinter():
    EndDocPrinter()     



@pytest.mark.xfail
def test_EndPage():
    EndPage()     



@pytest.mark.xfail
def test_EndPagePrinter():
    EndPagePrinter()     



@pytest.mark.xfail
def test_EnumForms():
    EnumForms()     



@pytest.mark.xfail
def test_EnumJobs():
    EnumJobs()     



@pytest.mark.xfail
def test_EnumMonitors():
    EnumMonitors()     



@pytest.mark.xfail
def test_EnumPorts():
    EnumPorts()     



@pytest.mark.xfail
def test_EnumPrintProcessorDatatypes():
    EnumPrintProcessorDatatypes()     



@pytest.mark.xfail
def test_EnumPrintProcessors():
    EnumPrintProcessors()     



@pytest.mark.xfail
def test_EnumPrinterDrivers():
    EnumPrinterDrivers()     



@pytest.mark.xfail
def test_EnumPrinters():
    EnumPrinters()     



@pytest.mark.xfail
def test_FlushPrinter():
    FlushPrinter()     



def test_GetDefaultPrinter():
    GetDefaultPrinter()     



def test_GetDefaultPrinterW():
    GetDefaultPrinterW()     



@pytest.mark.xfail
def test_GetDeviceCaps():
    GetDeviceCaps()     



@pytest.mark.xfail
def test_GetForm():
    GetForm()     



@pytest.mark.xfail
def test_GetJob():
    GetJob()     



def test_GetPrintProcessorDirectory():
    GetPrintProcessorDirectory()     



@pytest.mark.xfail
def test_GetPrinter():
    GetPrinter()     



def test_GetPrinterDriverDirectory():
    GetPrinterDriverDirectory()     



@pytest.mark.xfail
def test_OpenPrinter():
    OpenPrinter()     



@pytest.mark.xfail
def test_ScheduleJob():
    ScheduleJob()     



@pytest.mark.xfail
def test_SetDefaultPrinter():
    SetDefaultPrinter()     



@pytest.mark.xfail
def test_SetDefaultPrinterW():
    SetDefaultPrinterW()     



@pytest.mark.xfail
def test_SetForm():
    SetForm()     



@pytest.mark.xfail
def test_SetJob():
    SetJob()     



@pytest.mark.xfail
def test_SetPrinter():
    SetPrinter()     



@pytest.mark.xfail
def test_StartDoc():
    StartDoc()     



@pytest.mark.xfail
def test_StartDocPrinter():
    StartDocPrinter()     



@pytest.mark.xfail
def test_StartPage():
    StartPage()     



@pytest.mark.xfail
def test_StartPagePrinter():
    StartPagePrinter()     



@pytest.mark.xfail
def test_WritePrinter():
    WritePrinter()     


